Class: Google::Apis::AlloydbV1beta::ConnectionInfo
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::ConnectionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
ConnectionInfo singleton resource. https://google.aip.dev/156
Instance Attribute Summary collapse
-
#instance_uid ⇒ String
Output only.
-
#ip_address ⇒ String
Output only.
-
#name ⇒ String
The name of the ConnectionInfo singleton resource, e.g.: projects/
project/ locations/location/clusters//instances//connectionInfo This field currently has no semantic meaning. -
#pem_certificate_chain ⇒ Array<String>
Output only.
-
#psc_auto_dns_name ⇒ String
Output only.
-
#psc_dns_name ⇒ String
Output only.
-
#public_ip_address ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectionInfo
constructor
A new instance of ConnectionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectionInfo
Returns a new instance of ConnectionInfo.
1022 1023 1024 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_uid ⇒ String
Output only. The unique ID of the Instance.
Corresponds to the JSON property instanceUid
982 983 984 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 982 def instance_uid @instance_uid end |
#ip_address ⇒ String
Output only. The private network IP address for the Instance. This is the
default IP for the instance and is always created (even if enable_public_ip is
set). This is the connection endpoint for an end-user application.
Corresponds to the JSON property ipAddress
989 990 991 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 989 def ip_address @ip_address end |
#name ⇒ String
The name of the ConnectionInfo singleton resource, e.g.: projects/project/
locations/location/clusters//instances//connectionInfo This field
currently has no semantic meaning.
Corresponds to the JSON property name
996 997 998 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 996 def name @name end |
#pem_certificate_chain ⇒ Array<String>
Output only. The pem-encoded chain that may be used to verify the X.509
certificate. Expected to be in issuer-to-root order according to RFC 5246.
Corresponds to the JSON property pemCertificateChain
1002 1003 1004 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1002 def pem_certificate_chain @pem_certificate_chain end |
#psc_auto_dns_name ⇒ String
Output only. Specifies the DNS name to use with PSC service automation for the
Instance.
Corresponds to the JSON property pscAutoDnsName
1008 1009 1010 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1008 def psc_auto_dns_name @psc_auto_dns_name end |
#psc_dns_name ⇒ String
Output only. The DNS name to use with PSC for the Instance.
Corresponds to the JSON property pscDnsName
1013 1014 1015 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1013 def psc_dns_name @psc_dns_name end |
#public_ip_address ⇒ String
Output only. The public IP addresses for the Instance. This is available ONLY
when enable_public_ip is set. This is the connection endpoint for an end-user
application.
Corresponds to the JSON property publicIpAddress
1020 1021 1022 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1020 def public_ip_address @public_ip_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1027 def update!(**args) @instance_uid = args[:instance_uid] if args.key?(:instance_uid) @ip_address = args[:ip_address] if args.key?(:ip_address) @name = args[:name] if args.key?(:name) @pem_certificate_chain = args[:pem_certificate_chain] if args.key?(:pem_certificate_chain) @psc_auto_dns_name = args[:psc_auto_dns_name] if args.key?(:psc_auto_dns_name) @psc_dns_name = args[:psc_dns_name] if args.key?(:psc_dns_name) @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address) end |