Class: Google::Apis::AlloydbV1beta::ContinuousBackupInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

ContinuousBackupInfo describes the continuous backup properties of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContinuousBackupInfo

Returns a new instance of ContinuousBackupInfo.



1159
1160
1161
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#earliest_restorable_timeString

Output only. The earliest restorable time that can be restored to. If continuous backups and recovery was recently enabled, the earliest restorable time is the creation time of the earliest eligible backup within this cluster' s continuous backup recovery window. After a cluster has had continuous backups enabled for the duration of its recovery window, the earliest restorable time becomes "now minus the recovery window". For example, assuming a point in time recovery is attempted at 04/16/2025 3:23:00PM with a 14d recovery window, the earliest restorable time would be 04/02/2025 3:23:00PM. This field is only visible if the CLUSTER_VIEW_CONTINUOUS_BACKUP cluster view is provided. Corresponds to the JSON property earliestRestorableTime

Returns:

  • (String)


1141
1142
1143
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1141

def earliest_restorable_time
  @earliest_restorable_time
end

#enabled_timeString

Output only. When ContinuousBackup was most recently enabled. Set to null if ContinuousBackup is not enabled. Corresponds to the JSON property enabledTime

Returns:

  • (String)


1147
1148
1149
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1147

def enabled_time
  @enabled_time
end

#encryption_infoGoogle::Apis::AlloydbV1beta::EncryptionInfo

EncryptionInfo describes the encryption information of a cluster or a backup. Corresponds to the JSON property encryptionInfo



1152
1153
1154
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1152

def encryption_info
  @encryption_info
end

#scheduleArray<String>

Output only. Days of the week on which a continuous backup is taken. Corresponds to the JSON property schedule

Returns:

  • (Array<String>)


1157
1158
1159
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1157

def schedule
  @schedule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1164
1165
1166
1167
1168
1169
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1164

def update!(**args)
  @earliest_restorable_time = args[:earliest_restorable_time] if args.key?(:earliest_restorable_time)
  @enabled_time = args[:enabled_time] if args.key?(:enabled_time)
  @encryption_info = args[:encryption_info] if args.key?(:encryption_info)
  @schedule = args[:schedule] if args.key?(:schedule)
end