Class: Google::Apis::AlloydbV1beta::ContinuousBackupSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Message describing a ContinuousBackupSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContinuousBackupSource

Returns a new instance of ContinuousBackupSource.



1187
1188
1189
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Required. The source cluster from which to restore. This cluster must have continuous backup enabled for this operation to succeed. For the required format, see the comment on the Cluster.name field. Corresponds to the JSON property cluster

Returns:

  • (String)


1180
1181
1182
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1180

def cluster
  @cluster
end

#point_in_timeString

Required. The point in time to restore to. Corresponds to the JSON property pointInTime

Returns:

  • (String)


1185
1186
1187
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1185

def point_in_time
  @point_in_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1192
1193
1194
1195
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1192

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @point_in_time = args[:point_in_time] if args.key?(:point_in_time)
end