Class: Google::Apis::AlloydbV1beta::CsvExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Options for exporting data in CSV format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CsvExportOptions

Returns a new instance of CsvExportOptions.



1199
1200
1201
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#escape_characterString

Optional. Specifies the character that should appear before a data character that needs to be escaped. The default is the same as quote character. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property escapeCharacter

Returns:

  • (String)


1178
1179
1180
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1178

def escape_character
  @escape_character
end

#field_delimiterString

Optional. Specifies the character that separates columns within each row (line) of the file. The default is comma. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property fieldDelimiter

Returns:

  • (String)


1185
1186
1187
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1185

def field_delimiter
  @field_delimiter
end

#quote_characterString

Optional. Specifies the quoting character to be used when a data value is quoted. The default is double-quote. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property quoteCharacter

Returns:

  • (String)


1192
1193
1194
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1192

def quote_character
  @quote_character
end

#select_queryString

Required. The SELECT query used to extract the data. Corresponds to the JSON property selectQuery

Returns:

  • (String)


1197
1198
1199
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1197

def select_query
  @select_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1204
1205
1206
1207
1208
1209
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1204

def update!(**args)
  @escape_character = args[:escape_character] if args.key?(:escape_character)
  @field_delimiter = args[:field_delimiter] if args.key?(:field_delimiter)
  @quote_character = args[:quote_character] if args.key?(:quote_character)
  @select_query = args[:select_query] if args.key?(:select_query)
end