Class: Google::Apis::AlloydbV1beta::DenyMaintenancePeriod

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

DenyMaintenancePeriod definition. Excepting emergencies, maintenance will not be scheduled to start within this deny period. The start_date must be less than the end_date.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DenyMaintenancePeriod

Returns a new instance of DenyMaintenancePeriod.



1373
1374
1375
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dateGoogle::Apis::AlloydbV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



1352
1353
1354
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1352

def end_date
  @end_date
end

#start_dateGoogle::Apis::AlloydbV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



1364
1365
1366
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1364

def start_date
  @start_date
end

#timeGoogle::Apis::AlloydbV1beta::GoogleTypeTimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property time



1371
1372
1373
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1371

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1378
1379
1380
1381
1382
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1378

def update!(**args)
  @end_date = args[:end_date] if args.key?(:end_date)
  @start_date = args[:start_date] if args.key?(:start_date)
  @time = args[:time] if args.key?(:time)
end