Class: Google::Apis::AlloydbV1beta::Instance
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
An Instance is a computing unit that an end customer can connect to. It's the main unit of computing resources in AlloyDB.
Instance Attribute Summary collapse
-
#activation_policy ⇒ String
Optional.
-
#annotations ⇒ Hash<String,String>
Annotations to allow client tools to store small amount of arbitrary data.
-
#availability_type ⇒ String
Availability type of an Instance.
-
#client_connection_config ⇒ Google::Apis::AlloydbV1beta::ClientConnectionConfig
Client connection configuration Corresponds to the JSON property
clientConnectionConfig. -
#connection_pool_config ⇒ Google::Apis::AlloydbV1beta::ConnectionPoolConfig
Configuration for Managed Connection Pool (MCP).
-
#create_time ⇒ String
Output only.
-
#data_api_access ⇒ String
Optional.
-
#database_flags ⇒ Hash<String,String>
Database flags.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
User-settable and human-readable display name for the Instance.
-
#etag ⇒ String
For Resource freshness validation (https://google.aip.dev/154) Corresponds to the JSON property
etag. -
#gca_config ⇒ Google::Apis::AlloydbV1beta::GcaInstanceConfig
Instance level configuration parameters related to the Gemini Cloud Assist product.
-
#gce_zone ⇒ String
The Compute Engine zone that the instance should serve from, per https://cloud.
-
#gemini_config ⇒ Google::Apis::AlloydbV1beta::GeminiInstanceConfig
Deprecated and unused.
-
#instance_type ⇒ String
Required.
-
#ip_address ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs Corresponds to the JSON property
labels. -
#machine_config ⇒ Google::Apis::AlloydbV1beta::MachineConfig
MachineConfig describes the configuration of a machine.
-
#maintenance_version_name ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#network_config ⇒ Google::Apis::AlloydbV1beta::InstanceNetworkConfig
Metadata related to instance-level network configuration.
-
#nodes ⇒ Array<Google::Apis::AlloydbV1beta::Node>
Output only.
-
#observability_config ⇒ Google::Apis::AlloydbV1beta::ObservabilityInstanceConfig
Observability Instance specific configuration.
-
#outbound_public_ip_addresses ⇒ Array<String>
Output only.
-
#psc_instance_config ⇒ Google::Apis::AlloydbV1beta::PscInstanceConfig
PscInstanceConfig contains PSC related configuration at an instance level.
-
#psc_instance_info ⇒ Google::Apis::AlloydbV1beta::PscInstanceInfo
Information about the Private Service Connect (PSC) for the instance.
-
#public_ip_address ⇒ String
Output only.
-
#query_insights_config ⇒ Google::Apis::AlloydbV1beta::QueryInsightsInstanceConfig
QueryInsights Instance specific configuration.
-
#read_pool_config ⇒ Google::Apis::AlloydbV1beta::ReadPoolConfig
Configuration for a read pool instance.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_policy ⇒ Google::Apis::AlloydbV1beta::UpdatePolicy
Policy to be used while updating the instance.
-
#update_time ⇒ String
Output only.
-
#writable_node ⇒ Google::Apis::AlloydbV1beta::Node
Details of a single node in the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
2243 2244 2245 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_policy ⇒ String
Optional. Specifies whether an instance needs to spin up. Once the instance is
active, the activation policy can be updated to the NEVER to stop the
instance. Likewise, the activation policy can be updated to ALWAYS to start
the instance. There are restrictions around when an instance can/cannot be
activated (for example, a read pool instance should be stopped before stopping
primary etc.). Please refer to the API documentation for more details.
Corresponds to the JSON property activationPolicy
2019 2020 2021 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2019 def activation_policy @activation_policy end |
#annotations ⇒ Hash<String,String>
Annotations to allow client tools to store small amount of arbitrary data.
This is distinct from labels. https://google.aip.dev/128
Corresponds to the JSON property annotations
2025 2026 2027 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2025 def annotations @annotations end |
#availability_type ⇒ String
Availability type of an Instance. If empty, defaults to REGIONAL for primary
instances. For read pools, availability_type is always UNSPECIFIED. Instances
in the read pools are evenly distributed across available zones within the
region (i.e. read pools with more than one node will have a node in at least
two zones).
Corresponds to the JSON property availabilityType
2034 2035 2036 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2034 def availability_type @availability_type end |
#client_connection_config ⇒ Google::Apis::AlloydbV1beta::ClientConnectionConfig
Client connection configuration
Corresponds to the JSON property clientConnectionConfig
2039 2040 2041 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2039 def client_connection_config @client_connection_config end |
#connection_pool_config ⇒ Google::Apis::AlloydbV1beta::ConnectionPoolConfig
Configuration for Managed Connection Pool (MCP).
Corresponds to the JSON property connectionPoolConfig
2044 2045 2046 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2044 def connection_pool_config @connection_pool_config end |
#create_time ⇒ String
Output only. Create time stamp
Corresponds to the JSON property createTime
2049 2050 2051 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2049 def create_time @create_time end |
#data_api_access ⇒ String
Optional. Controls whether the Data API is enabled for this instance. When
enabled, this allows authorized users to connect to the instance from the
public internet using the executeSql API, even for private IP instances. If
this is not specified, the data API is enabled by default for Google internal
services like AlloyDB Studio. Disable it explicitly to disallow Google
internal services as well.
Corresponds to the JSON property dataApiAccess
2059 2060 2061 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2059 def data_api_access @data_api_access end |
#database_flags ⇒ Hash<String,String>
Database flags. Set at the instance level. They are copied from the primary
instance on secondary instance creation. Flags that have restrictions default
to the value at primary instance on read instances during creation. Read
instances can set new flags or override existing flags that are relevant for
reads, for example, for enabling columnar cache on a read instance. Flags set
on read instance might or might not be present on the primary instance. This
is a list of "key": "value" pairs. "key": The name of the flag. These flags
are passed at instance setup time, so include both server options and system
variables for Postgres. Flags are specified with underscores, not hyphens. "
value": The value of the flag. Booleans are set to on for true and off
for false. This field must be omitted if the flag doesn't take a value.
Corresponds to the JSON property databaseFlags
2074 2075 2076 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2074 def database_flags @database_flags end |
#delete_time ⇒ String
Output only. Delete time stamp
Corresponds to the JSON property deleteTime
2079 2080 2081 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2079 def delete_time @delete_time end |
#display_name ⇒ String
User-settable and human-readable display name for the Instance.
Corresponds to the JSON property displayName
2084 2085 2086 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2084 def display_name @display_name end |
#etag ⇒ String
For Resource freshness validation (https://google.aip.dev/154)
Corresponds to the JSON property etag
2089 2090 2091 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2089 def etag @etag end |
#gca_config ⇒ Google::Apis::AlloydbV1beta::GcaInstanceConfig
Instance level configuration parameters related to the Gemini Cloud Assist
product.
Corresponds to the JSON property gcaConfig
2095 2096 2097 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2095 def gca_config @gca_config end |
#gce_zone ⇒ String
The Compute Engine zone that the instance should serve from, per https://cloud.
google.com/compute/docs/regions-zones This can ONLY be specified for ZONAL
instances. If present for a REGIONAL instance, an error will be thrown. If
this is absent for a ZONAL instance, instance is created in a random zone with
available capacity.
Corresponds to the JSON property gceZone
2104 2105 2106 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2104 def gce_zone @gce_zone end |
#gemini_config ⇒ Google::Apis::AlloydbV1beta::GeminiInstanceConfig
Deprecated and unused. This message will be removed in the near future.
Corresponds to the JSON property geminiConfig
2109 2110 2111 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2109 def gemini_config @gemini_config end |
#instance_type ⇒ String
Required. The type of the instance. Specified at creation time.
Corresponds to the JSON property instanceType
2114 2115 2116 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2114 def instance_type @instance_type end |
#ip_address ⇒ String
Output only. The IP address for the Instance. This is the connection endpoint
for an end-user application.
Corresponds to the JSON property ipAddress
2120 2121 2122 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2120 def ip_address @ip_address end |
#labels ⇒ Hash<String,String>
Labels as key value pairs
Corresponds to the JSON property labels
2125 2126 2127 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2125 def labels @labels end |
#machine_config ⇒ Google::Apis::AlloydbV1beta::MachineConfig
MachineConfig describes the configuration of a machine.
Corresponds to the JSON property machineConfig
2130 2131 2132 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2130 def machine_config @machine_config end |
#maintenance_version_name ⇒ String
Output only. Maintenance version of the instance, for example: POSTGRES_15.
2025_07_15.04_00. Output only. Update this field via the parent cluster's
maintenance_version field(s).
Corresponds to the JSON property maintenanceVersionName
2137 2138 2139 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2137 def maintenance_version_name @maintenance_version_name end |
#name ⇒ String
Output only. The name of the instance resource with the format: * projects/
project/locations/region/clusters/cluster_id/instances/instance_id
where the cluster and instance ID segments should satisfy the regex expression
[a-z]([a-z0-9-]0,61[a-z0-9])?, e.g. 1-63 characters of lowercase letters,
numbers, and dashes, starting with a letter, and ending with a letter or
number. For more details see https://google.aip.dev/122. The prefix of the
instance resource name is the name of the parent resource: * projects/project
/locations/region/clusters/cluster_id
Corresponds to the JSON property name
2149 2150 2151 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2149 def name @name end |
#network_config ⇒ Google::Apis::AlloydbV1beta::InstanceNetworkConfig
Metadata related to instance-level network configuration.
Corresponds to the JSON property networkConfig
2154 2155 2156 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2154 def network_config @network_config end |
#nodes ⇒ Array<Google::Apis::AlloydbV1beta::Node>
Output only. List of available read-only VMs in this instance, including the
standby for a PRIMARY instance.
Corresponds to the JSON property nodes
2160 2161 2162 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2160 def nodes @nodes end |
#observability_config ⇒ Google::Apis::AlloydbV1beta::ObservabilityInstanceConfig
Observability Instance specific configuration.
Corresponds to the JSON property observabilityConfig
2165 2166 2167 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2165 def observability_config @observability_config end |
#outbound_public_ip_addresses ⇒ Array<String>
Output only. All outbound public IP addresses configured for the instance.
Corresponds to the JSON property outboundPublicIpAddresses
2170 2171 2172 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2170 def outbound_public_ip_addresses @outbound_public_ip_addresses end |
#psc_instance_config ⇒ Google::Apis::AlloydbV1beta::PscInstanceConfig
PscInstanceConfig contains PSC related configuration at an instance level.
Corresponds to the JSON property pscInstanceConfig
2175 2176 2177 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2175 def psc_instance_config @psc_instance_config end |
#psc_instance_info ⇒ Google::Apis::AlloydbV1beta::PscInstanceInfo
Information about the Private Service Connect (PSC) for the instance.
Corresponds to the JSON property pscInstanceInfo
2180 2181 2182 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2180 def psc_instance_info @psc_instance_info end |
#public_ip_address ⇒ String
Output only. The public IP addresses for the Instance. This is available ONLY
when enable_public_ip is set. This is the connection endpoint for an end-user
application.
Corresponds to the JSON property publicIpAddress
2187 2188 2189 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2187 def public_ip_address @public_ip_address end |
#query_insights_config ⇒ Google::Apis::AlloydbV1beta::QueryInsightsInstanceConfig
QueryInsights Instance specific configuration.
Corresponds to the JSON property queryInsightsConfig
2192 2193 2194 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2192 def query_insights_config @query_insights_config end |
#read_pool_config ⇒ Google::Apis::AlloydbV1beta::ReadPoolConfig
Configuration for a read pool instance.
Corresponds to the JSON property readPoolConfig
2197 2198 2199 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2197 def read_pool_config @read_pool_config end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Reconciling (https://google.aip.dev/128#reconciliation). Set to
true if the current state of Instance does not match the user's intended state,
and the service is actively updating the resource to reconcile them. This can
happen due to user-triggered updates or system actions like failover or
maintenance.
Corresponds to the JSON property reconciling
2206 2207 2208 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2206 def reconciling @reconciling end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
2212 2213 2214 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2212 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The current serving state of the instance.
Corresponds to the JSON property state
2218 2219 2220 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2218 def state @state end |
#uid ⇒ String
Output only. The system-generated UID of the resource. The UID is assigned
when the resource is created, and it is retained until it is deleted.
Corresponds to the JSON property uid
2224 2225 2226 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2224 def uid @uid end |
#update_policy ⇒ Google::Apis::AlloydbV1beta::UpdatePolicy
Policy to be used while updating the instance.
Corresponds to the JSON property updatePolicy
2229 2230 2231 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2229 def update_policy @update_policy end |
#update_time ⇒ String
Output only. Update time stamp
Corresponds to the JSON property updateTime
2234 2235 2236 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2234 def update_time @update_time end |
#writable_node ⇒ Google::Apis::AlloydbV1beta::Node
Details of a single node in the instance. Nodes in an AlloyDB instance are
ephemeral, they can change during update, failover, autohealing and resize
operations.
Corresponds to the JSON property writableNode
2241 2242 2243 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2241 def writable_node @writable_node end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2248 def update!(**args) @activation_policy = args[:activation_policy] if args.key?(:activation_policy) @annotations = args[:annotations] if args.key?(:annotations) @availability_type = args[:availability_type] if args.key?(:availability_type) @client_connection_config = args[:client_connection_config] if args.key?(:client_connection_config) @connection_pool_config = args[:connection_pool_config] if args.key?(:connection_pool_config) @create_time = args[:create_time] if args.key?(:create_time) @data_api_access = args[:data_api_access] if args.key?(:data_api_access) @database_flags = args[:database_flags] if args.key?(:database_flags) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @gca_config = args[:gca_config] if args.key?(:gca_config) @gce_zone = args[:gce_zone] if args.key?(:gce_zone) @gemini_config = args[:gemini_config] if args.key?(:gemini_config) @instance_type = args[:instance_type] if args.key?(:instance_type) @ip_address = args[:ip_address] if args.key?(:ip_address) @labels = args[:labels] if args.key?(:labels) @machine_config = args[:machine_config] if args.key?(:machine_config) @maintenance_version_name = args[:maintenance_version_name] if args.key?(:maintenance_version_name) @name = args[:name] if args.key?(:name) @network_config = args[:network_config] if args.key?(:network_config) @nodes = args[:nodes] if args.key?(:nodes) @observability_config = args[:observability_config] if args.key?(:observability_config) @outbound_public_ip_addresses = args[:outbound_public_ip_addresses] if args.key?(:outbound_public_ip_addresses) @psc_instance_config = args[:psc_instance_config] if args.key?(:psc_instance_config) @psc_instance_info = args[:psc_instance_info] if args.key?(:psc_instance_info) @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address) @query_insights_config = args[:query_insights_config] if args.key?(:query_insights_config) @read_pool_config = args[:read_pool_config] if args.key?(:read_pool_config) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_policy = args[:update_policy] if args.key?(:update_policy) @update_time = args[:update_time] if args.key?(:update_time) @writable_node = args[:writable_node] if args.key?(:writable_node) end |