Class: Google::Apis::AlloydbV1beta::IntegerRestrictions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Restrictions on INTEGER type values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IntegerRestrictions

Returns a new instance of IntegerRestrictions.



2363
2364
2365
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_valueFixnum

The maximum value that can be specified, if applicable. Corresponds to the JSON property maxValue

Returns:

  • (Fixnum)


2356
2357
2358
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2356

def max_value
  @max_value
end

#min_valueFixnum

The minimum value that can be specified, if applicable. Corresponds to the JSON property minValue

Returns:

  • (Fixnum)


2361
2362
2363
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2361

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2368
2369
2370
2371
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2368

def update!(**args)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end