Class: Google::Apis::AlloydbV1beta::ListBackupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::ListBackupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Message for response to listing Backups
Instance Attribute Summary collapse
-
#backups ⇒ Array<Google::Apis::AlloydbV1beta::Backup>
The list of Backup Corresponds to the JSON property
backups. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupsResponse
constructor
A new instance of ListBackupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupsResponse
Returns a new instance of ListBackupsResponse.
2375 2376 2377 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2375 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backups ⇒ Array<Google::Apis::AlloydbV1beta::Backup>
The list of Backup
Corresponds to the JSON property backups
2363 2364 2365 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2363 def backups @backups end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2368 2369 2370 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2368 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2373 2374 2375 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2373 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2380 2381 2382 2383 2384 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2380 def update!(**args) @backups = args[:backups] if args.key?(:backups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |