Class: Google::Apis::AlloydbV1beta::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::AlloydbV1beta::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
2520 2521 2522 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
2505 2506 2507 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2505 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::AlloydbV1beta::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
2510 2511 2512 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2510 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
2518 2519 2520 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2518 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2525 2526 2527 2528 2529 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2525 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |