Class: Google::Apis::AlloydbV1beta::Policy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Policy for the autoscaler.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Policy

Returns a new instance of Policy.



3054
3055
3056
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3054

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cool_down_period_secFixnum

The period of time in seconds after a new node is created before the autoscaler will incorporate its resource usage (e.g. CPU utilization) into the autoscaling recommendation algorithm. Corresponds to the JSON property coolDownPeriodSec

Returns:

  • (Fixnum)


3035
3036
3037
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3035

def cool_down_period_sec
  @cool_down_period_sec
end

#cpu_utilizationGoogle::Apis::AlloydbV1beta::CpuUtilization

CPU utilization policy for the autoscaler. Corresponds to the JSON property cpuUtilization



3040
3041
3042
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3040

def cpu_utilization
  @cpu_utilization
end

#enabledBoolean Also known as: enabled?

If true, autoscaling is enabled for the instance. If not set, the default value is false. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


3046
3047
3048
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3046

def enabled
  @enabled
end

#max_node_countFixnum

Maximum number of nodes for the autoscaler. Corresponds to the JSON property maxNodeCount

Returns:

  • (Fixnum)


3052
3053
3054
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3052

def max_node_count
  @max_node_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3059
3060
3061
3062
3063
3064
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3059

def update!(**args)
  @cool_down_period_sec = args[:cool_down_period_sec] if args.key?(:cool_down_period_sec)
  @cpu_utilization = args[:cpu_utilization] if args.key?(:cpu_utilization)
  @enabled = args[:enabled] if args.key?(:enabled)
  @max_node_count = args[:max_node_count] if args.key?(:max_node_count)
end