Class: Google::Apis::AlloydbV1beta::PscAutoConnectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Configuration for setting up PSC service automation. Consumer projects in the configs will be allowlisted automatically for the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscAutoConnectionConfig

Returns a new instance of PscAutoConnectionConfig.



3167
3168
3169
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

The consumer network for the PSC service automation, example: "projects/vpc- host-project/global/networks/default". The consumer network might be hosted a different project than the consumer project. Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


3128
3129
3130
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3128

def consumer_network
  @consumer_network
end

#consumer_network_statusString

Output only. The status of the service connection policy. Possible values: " STATE_UNSPECIFIED" - Default state, when Connection Map is created initially. " VALID" - Set when policy and map configuration is valid, and their matching can lead to allowing creation of PSC Connections subject to other constraints like connections limit. "CONNECTION_POLICY_MISSING" - No Service Connection Policy found for this network and Service Class "POLICY_LIMIT_REACHED" - Service Connection Policy limit reached for this network and Service Class " CONSUMER_INSTANCE_PROJECT_NOT_ALLOWLISTED" - The consumer instance project is not in AllowedGoogleProducersResourceHierarchyLevels of the matching ServiceConnectionPolicy. Corresponds to the JSON property consumerNetworkStatus

Returns:

  • (String)


3142
3143
3144
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3142

def consumer_network_status
  @consumer_network_status
end

#consumer_projectString

The consumer project to which the PSC service automation endpoint will be created. Corresponds to the JSON property consumerProject

Returns:

  • (String)


3148
3149
3150
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3148

def consumer_project
  @consumer_project
end

#ip_addressString

Output only. The IP address of the PSC service automation endpoint. Corresponds to the JSON property ipAddress

Returns:

  • (String)


3153
3154
3155
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3153

def ip_address
  @ip_address
end

#statusString

Output only. The status of the PSC service automation connection. Possible values: "STATE_UNSPECIFIED" - An invalid state as the default case. "ACTIVE" - The connection has been created successfully. "FAILED" - The connection is not functional since some resources on the connection fail to be created. " CREATING" - The connection is being created. "DELETING" - The connection is being deleted. "CREATE_REPAIRING" - The connection is being repaired to complete creation. "DELETE_REPAIRING" - The connection is being repaired to complete deletion. Corresponds to the JSON property status

Returns:

  • (String)


3165
3166
3167
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3165

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3172
3173
3174
3175
3176
3177
3178
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3172

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @consumer_network_status = args[:consumer_network_status] if args.key?(:consumer_network_status)
  @consumer_project = args[:consumer_project] if args.key?(:consumer_project)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @status = args[:status] if args.key?(:status)
end