Class: Google::Apis::AlloydbV1beta::PscConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

PscConfig contains PSC related configuration at a cluster level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscConfig

Returns a new instance of PscConfig.



3223
3224
3225
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#psc_enabledBoolean Also known as: psc_enabled?

Optional. Create an instance that allows connections from Private Service Connect endpoints to the instance. Corresponds to the JSON property pscEnabled

Returns:

  • (Boolean)


3214
3215
3216
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3214

def psc_enabled
  @psc_enabled
end

#service_owned_project_numberFixnum

Output only. The project number that needs to be allowlisted on the network attachment to enable outbound connectivity. Corresponds to the JSON property serviceOwnedProjectNumber

Returns:

  • (Fixnum)


3221
3222
3223
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3221

def service_owned_project_number
  @service_owned_project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3228
3229
3230
3231
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3228

def update!(**args)
  @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled)
  @service_owned_project_number = args[:service_owned_project_number] if args.key?(:service_owned_project_number)
end