Class: Google::Apis::AlloydbV1beta::PscInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::PscInstanceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
PscInstanceConfig contains PSC related configuration at an instance level.
Instance Attribute Summary collapse
-
#allowed_consumer_projects ⇒ Array<String>
Optional.
-
#psc_auto_connections ⇒ Array<Google::Apis::AlloydbV1beta::PscAutoConnectionConfig>
Optional.
-
#psc_dns_name ⇒ String
Output only.
-
#psc_interface_configs ⇒ Array<Google::Apis::AlloydbV1beta::PscInterfaceConfig>
Optional.
-
#service_attachment_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscInstanceConfig
constructor
A new instance of PscInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscInstanceConfig
Returns a new instance of PscInstanceConfig.
3244 3245 3246 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_consumer_projects ⇒ Array<String>
Optional. List of consumer projects that are allowed to create PSC endpoints
to service-attachments to this instance.
Corresponds to the JSON property allowedConsumerProjects
3217 3218 3219 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3217 def allowed_consumer_projects @allowed_consumer_projects end |
#psc_auto_connections ⇒ Array<Google::Apis::AlloydbV1beta::PscAutoConnectionConfig>
Optional. Configurations for setting up PSC service automation.
Corresponds to the JSON property pscAutoConnections
3222 3223 3224 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3222 def psc_auto_connections @psc_auto_connections end |
#psc_dns_name ⇒ String
Output only. The DNS name of the instance for PSC connectivity. Name
convention: ...alloydb-psc.goog
Corresponds to the JSON property pscDnsName
3228 3229 3230 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3228 def psc_dns_name @psc_dns_name end |
#psc_interface_configs ⇒ Array<Google::Apis::AlloydbV1beta::PscInterfaceConfig>
Optional. Configurations for setting up PSC interfaces attached to the
instance which are used for outbound connectivity. Only primary instances can
have PSC interface attached. Currently we only support 0 or 1 PSC interface.
Corresponds to the JSON property pscInterfaceConfigs
3235 3236 3237 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3235 def psc_interface_configs @psc_interface_configs end |
#service_attachment_link ⇒ String
Output only. The service attachment created when Private Service Connect (PSC)
is enabled for the instance. The name of the resource will be in the format of
projects//regions//serviceAttachments/
Corresponds to the JSON property serviceAttachmentLink
3242 3243 3244 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3242 def @service_attachment_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3249 3250 3251 3252 3253 3254 3255 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3249 def update!(**args) @allowed_consumer_projects = args[:allowed_consumer_projects] if args.key?(:allowed_consumer_projects) @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections) @psc_dns_name = args[:psc_dns_name] if args.key?(:psc_dns_name) @psc_interface_configs = args[:psc_interface_configs] if args.key?(:psc_interface_configs) @service_attachment_link = args[:service_attachment_link] if args.key?(:service_attachment_link) end |