Class: Google::Apis::AlloydbV1beta::PscInstanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Information about the Private Service Connect (PSC) for the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscInstanceInfo

Returns a new instance of PscInstanceInfo.



3354
3355
3356
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_psc_auto_connection_policyBoolean Also known as: effective_psc_auto_connection_policy?

Output only. Indicates if the PSC auto connection policy is enabled for the instance. For older instances, this will be off by default, but for newer instances, this will be auto-enabled. Corresponds to the JSON property effectivePscAutoConnectionPolicy

Returns:

  • (Boolean)


3334
3335
3336
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3334

def effective_psc_auto_connection_policy
  @effective_psc_auto_connection_policy
end

#effective_psc_auto_dns_enabledBoolean Also known as: effective_psc_auto_dns_enabled?

Output only. The effective state of the PSC auto DNS for the instance. Corresponds to the JSON property effectivePscAutoDnsEnabled

Returns:

  • (Boolean)


3340
3341
3342
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3340

def effective_psc_auto_dns_enabled
  @effective_psc_auto_dns_enabled
end

#psc_auto_dns_namesArray<String>

Output only. Specifies the auto DNS names for the instance. Corresponds to the JSON property pscAutoDnsNames

Returns:

  • (Array<String>)


3346
3347
3348
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3346

def psc_auto_dns_names
  @psc_auto_dns_names
end

#service_connection_policyString

Output only. The PSC service connection policy name. The format is "projects// regions//serviceConnectionPolicies/" Corresponds to the JSON property serviceConnectionPolicy

Returns:

  • (String)


3352
3353
3354
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3352

def service_connection_policy
  @service_connection_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3359
3360
3361
3362
3363
3364
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3359

def update!(**args)
  @effective_psc_auto_connection_policy = args[:effective_psc_auto_connection_policy] if args.key?(:effective_psc_auto_connection_policy)
  @effective_psc_auto_dns_enabled = args[:effective_psc_auto_dns_enabled] if args.key?(:effective_psc_auto_dns_enabled)
  @psc_auto_dns_names = args[:psc_auto_dns_names] if args.key?(:psc_auto_dns_names)
  @service_connection_policy = args[:service_connection_policy] if args.key?(:service_connection_policy)
end