Class: Google::Apis::AlloydbV1beta::PscInterfaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Configuration for setting up a PSC interface to enable outbound connectivity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscInterfaceConfig

Returns a new instance of PscInterfaceConfig.



3271
3272
3273
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_attachment_resourceString

The network attachment resource created in the consumer network to which the PSC interface will be linked. This is of the format: "projects/$ CONSUMER_PROJECT/regions/$REGION/networkAttachments/$ NETWORK_ATTACHMENT_NAME". The network attachment must be in the same region as the instance. Corresponds to the JSON property networkAttachmentResource

Returns:

  • (String)


3269
3270
3271
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3269

def network_attachment_resource
  @network_attachment_resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3276
3277
3278
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3276

def update!(**args)
  @network_attachment_resource = args[:network_attachment_resource] if args.key?(:network_attachment_resource)
end