Class: Google::Apis::AlloydbV1beta::QuantityBasedRetention

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

A quantity based policy specifies that a certain number of the most recent successful backups should be retained.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuantityBasedRetention

Returns a new instance of QuantityBasedRetention.



3410
3411
3412
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

The number of backups to retain. Corresponds to the JSON property count

Returns:

  • (Fixnum)


3408
3409
3410
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3408

def count
  @count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3415
3416
3417
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3415

def update!(**args)
  @count = args[:count] if args.key?(:count)
end