Class: Google::Apis::AlloydbV1beta::RestoreFromCloudSqlRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Message for registering Restoring from CloudSQL resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreFromCloudSqlRequest

Returns a new instance of RestoreFromCloudSqlRequest.



3563
3564
3565
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3563

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloudsql_backup_run_sourceGoogle::Apis::AlloydbV1beta::CloudSqlBackupRunSource

The source CloudSQL backup resource. Corresponds to the JSON property cloudsqlBackupRunSource



3549
3550
3551
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3549

def cloudsql_backup_run_source
  @cloudsql_backup_run_source
end

#clusterGoogle::Apis::AlloydbV1beta::Cluster

A cluster is a collection of regional AlloyDB resources. It can include a primary instance and one or more read pool instances. All cluster resources share a storage layer, which scales as needed. Corresponds to the JSON property cluster



3556
3557
3558
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3556

def cluster
  @cluster
end

#cluster_idString

Required. ID of the requesting object. Corresponds to the JSON property clusterId

Returns:

  • (String)


3561
3562
3563
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3561

def cluster_id
  @cluster_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3568
3569
3570
3571
3572
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3568

def update!(**args)
  @cloudsql_backup_run_source = args[:cloudsql_backup_run_source] if args.key?(:cloudsql_backup_run_source)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
end