Class: Google::Apis::AlloydbV1beta::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
A schedule for the autoscaler.
Instance Attribute Summary collapse
-
#cron_expression ⇒ String
Cron expression for the triggering the schedule.
-
#description ⇒ String
Description of the schedule.
-
#disabled ⇒ Boolean
(also: #disabled?)
If true, the schedule is disabled.
-
#duration_sec ⇒ Fixnum
Duration of the schedule.
-
#min_node_count ⇒ Fixnum
Minimum number of nodes in while the schedule is active.
-
#name ⇒ String
Name of the schedule.
-
#time_zone ⇒ String
The location-based IANA time zone for interpreting the schedule's start time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
3725 3726 3727 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cron_expression ⇒ String
Cron expression for the triggering the schedule. See https://cloud.google.com/
compute/docs/autoscaler/scaling-schedules#cron_expressions for the syntax.
Corresponds to the JSON property cronExpression
3691 3692 3693 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3691 def cron_expression @cron_expression end |
#description ⇒ String
Description of the schedule.
Corresponds to the JSON property description
3696 3697 3698 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3696 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
If true, the schedule is disabled.
Corresponds to the JSON property disabled
3701 3702 3703 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3701 def disabled @disabled end |
#duration_sec ⇒ Fixnum
Duration of the schedule.
Corresponds to the JSON property durationSec
3707 3708 3709 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3707 def duration_sec @duration_sec end |
#min_node_count ⇒ Fixnum
Minimum number of nodes in while the schedule is active.
Corresponds to the JSON property minNodeCount
3712 3713 3714 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3712 def min_node_count @min_node_count end |
#name ⇒ String
Name of the schedule.
Corresponds to the JSON property name
3717 3718 3719 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3717 def name @name end |
#time_zone ⇒ String
The location-based IANA time zone for interpreting the schedule's start time.
If no time zone is provided, UTC is used by default.
Corresponds to the JSON property timeZone
3723 3724 3725 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3723 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3730 def update!(**args) @cron_expression = args[:cron_expression] if args.key?(:cron_expression) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @duration_sec = args[:duration_sec] if args.key?(:duration_sec) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) @name = args[:name] if args.key?(:name) @time_zone = args[:time_zone] if args.key?(:time_zone) end |