Class: Google::Apis::AlloydbV1beta::StageInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Stage information for different stages in the upgrade process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StageInfo

Returns a new instance of StageInfo.



3762
3763
3764
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#logs_urlString

logs_url is the URL for the logs associated with a stage if that stage has logs. Right now, only three stages have logs: ALLOYDB_PRECHECK, PG_UPGRADE_CHECK, PRIMARY_INSTANCE_UPGRADE. Corresponds to the JSON property logsUrl

Returns:

  • (String)


3750
3751
3752
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3750

def logs_url
  @logs_url
end

#stageString

The stage. Corresponds to the JSON property stage

Returns:

  • (String)


3755
3756
3757
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3755

def stage
  @stage
end

#statusString

Status of the stage. Corresponds to the JSON property status

Returns:

  • (String)


3760
3761
3762
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3760

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3767
3768
3769
3770
3771
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3767

def update!(**args)
  @logs_url = args[:logs_url] if args.key?(:logs_url)
  @stage = args[:stage] if args.key?(:stage)
  @status = args[:status] if args.key?(:status)
end