Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainCompliance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Contains compliance information about a security standard indicating unmet recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainCompliance

Returns a new instance of StorageDatabasecenterPartnerapiV1mainCompliance.



4100
4101
4102
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#standardString

Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP. Corresponds to the JSON property standard

Returns:

  • (String)


4093
4094
4095
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4093

def standard
  @standard
end

#versionString

Version of the standard or benchmark, for example, 1.1 Corresponds to the JSON property version

Returns:

  • (String)


4098
4099
4100
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4098

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4105
4106
4107
4108
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4105

def update!(**args)
  @standard = args[:standard] if args.key?(:standard)
  @version = args[:version] if args.key?(:version)
end