Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData

Returns a new instance of StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData.



4155
4156
4157
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_resource_nameString

Required. Full Resource name of the source resource. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


4132
4133
4134
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4132

def full_resource_name
  @full_resource_name
end

#last_refresh_timeString

Required. Last time signal was refreshed Corresponds to the JSON property lastRefreshTime

Returns:

  • (String)


4137
4138
4139
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4137

def last_refresh_time
  @last_refresh_time
end

#resource_idGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



4142
4143
4144
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4142

def resource_id
  @resource_id
end

#signal_bool_valueBoolean Also known as: signal_bool_value?

Signal data for boolean signals. Corresponds to the JSON property signalBoolValue

Returns:

  • (Boolean)


4147
4148
4149
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4147

def signal_bool_value
  @signal_bool_value
end

#signal_typeString

Required. Signal type of the signal Corresponds to the JSON property signalType

Returns:

  • (String)


4153
4154
4155
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4153

def signal_type
  @signal_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4160
4161
4162
4163
4164
4165
4166
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4160

def update!(**args)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value)
  @signal_type = args[:signal_type] if args.key?(:signal_type)
end