Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData.



4760
4761
4762
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_runGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupRun

A backup run. Corresponds to the JSON property backupRun



4716
4717
4718
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4716

def backup_run
  @backup_run
end

#full_resource_nameString

Required. Full Resource name of the source resource. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


4721
4722
4723
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4721

def full_resource_name
  @full_resource_name
end

#last_refresh_timeString

Required. Last time signal was refreshed Corresponds to the JSON property lastRefreshTime

Returns:

  • (String)


4726
4727
4728
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4726

def last_refresh_time
  @last_refresh_time
end

#locationString

Required. Resource location. Corresponds to the JSON property location

Returns:

  • (String)


4731
4732
4733
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4731

def location
  @location
end

#resource_idGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



4736
4737
4738
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4736

def resource_id
  @resource_id
end

#signal_bool_valueBoolean Also known as: signal_bool_value?

Deprecated: Use signal_metadata_list instead. Corresponds to the JSON property signalBoolValue

Returns:

  • (Boolean)


4741
4742
4743
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4741

def signal_bool_value
  @signal_bool_value
end

#signal_metadata_listArray<Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainSignalMetadata>

This will support array of OneOf signal metadata information for a given signal type. Corresponds to the JSON property signalMetadataList



4748
4749
4750
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4748

def 
  @signal_metadata_list
end

#signal_stateString

Required. Output only. Signal state of the signal Corresponds to the JSON property signalState

Returns:

  • (String)


4753
4754
4755
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4753

def signal_state
  @signal_state
end

#signal_typeString

Required. Signal type of the signal Corresponds to the JSON property signalType

Returns:

  • (String)


4758
4759
4760
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4758

def signal_type
  @signal_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4765

def update!(**args)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time)
  @location = args[:location] if args.key?(:location)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value)
  @signal_metadata_list = args[:signal_metadata_list] if args.key?(:signal_metadata_list)
  @signal_state = args[:signal_state] if args.key?(:signal_state)
  @signal_type = args[:signal_type] if args.key?(:signal_type)
end