Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainIpAddress
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainIpAddress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Used to send IP address information for a database resource.
Instance Attribute Summary collapse
-
#private_ip ⇒ String
The private IP address assigned to the resource within a Virtual Private Cloud (VPC).
-
#public_ip ⇒ String
The public IP address assigned to the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainIpAddress
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainIpAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainIpAddress
Returns a new instance of StorageDatabasecenterPartnerapiV1mainIpAddress.
4932 4933 4934 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_ip ⇒ String
The private IP address assigned to the resource within a Virtual Private Cloud
(VPC). This IP is only reachable from within the same VPC network. Stored in
standard string format (e.g., "10.0.0.2").
Corresponds to the JSON property privateIp
4924 4925 4926 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4924 def private_ip @private_ip end |
#public_ip ⇒ String
The public IP address assigned to the resource. This IP is reachable from the
internet. Stored in standard string format (e.g., "34.72.1.1").
Corresponds to the JSON property publicIp
4930 4931 4932 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4930 def public_ip @public_ip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4937 4938 4939 4940 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4937 def update!(**args) @private_ip = args[:private_ip] if args.key?(:private_ip) @public_ip = args[:public_ip] if args.key?(:public_ip) end |