Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Disable validation warnings
Instance Attribute Summary collapse
-
#current_version_release_date ⇒ Google::Apis::AlloydbV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#deny_maintenance_schedules ⇒ Array<Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule>
Optional.
-
#is_instance_stopped ⇒ Boolean
(also: #is_instance_stopped?)
Optional.
-
#maintenance_schedule ⇒ Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule
Disable validation warnings Corresponds to the JSON property
maintenanceSchedule. -
#maintenance_state ⇒ String
Output only.
-
#maintenance_version ⇒ String
Optional.
-
#next_available_maintenance_versions ⇒ Array<String>
Optional.
-
#upcoming_maintenance ⇒ Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainUpcomingMaintenance
Disable validation warnings Corresponds to the JSON property
upcomingMaintenance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo
Returns a new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo.
5180 5181 5182 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5180 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_version_release_date ⇒ Google::Apis::AlloydbV1beta::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property currentVersionReleaseDate
5142 5143 5144 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5142 def current_version_release_date @current_version_release_date end |
#deny_maintenance_schedules ⇒ Array<Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule>
Optional. Disable validation warnings
Corresponds to the JSON property denyMaintenanceSchedules
5147 5148 5149 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5147 def deny_maintenance_schedules @deny_maintenance_schedules end |
#is_instance_stopped ⇒ Boolean Also known as: is_instance_stopped?
Optional. Disable validation warnings
Corresponds to the JSON property isInstanceStopped
5152 5153 5154 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5152 def is_instance_stopped @is_instance_stopped end |
#maintenance_schedule ⇒ Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule
Disable validation warnings
Corresponds to the JSON property maintenanceSchedule
5158 5159 5160 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5158 def maintenance_schedule @maintenance_schedule end |
#maintenance_state ⇒ String
Output only. Disable validation warnings
Corresponds to the JSON property maintenanceState
5163 5164 5165 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5163 def maintenance_state @maintenance_state end |
#maintenance_version ⇒ String
Optional. Disable validation warnings
Corresponds to the JSON property maintenanceVersion
5168 5169 5170 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5168 def maintenance_version @maintenance_version end |
#next_available_maintenance_versions ⇒ Array<String>
Optional. Disable validation warnings
Corresponds to the JSON property nextAvailableMaintenanceVersions
5173 5174 5175 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5173 def next_available_maintenance_versions @next_available_maintenance_versions end |
#upcoming_maintenance ⇒ Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainUpcomingMaintenance
Disable validation warnings
Corresponds to the JSON property upcomingMaintenance
5178 5179 5180 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5178 def upcoming_maintenance @upcoming_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5185 def update!(**args) @current_version_release_date = args[:current_version_release_date] if args.key?(:current_version_release_date) @deny_maintenance_schedules = args[:deny_maintenance_schedules] if args.key?(:deny_maintenance_schedules) @is_instance_stopped = args[:is_instance_stopped] if args.key?(:is_instance_stopped) @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule) @maintenance_state = args[:maintenance_state] if args.key?(:maintenance_state) @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version) @next_available_maintenance_versions = args[:next_available_maintenance_versions] if args.key?(:next_available_maintenance_versions) @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance) end |