Class: Google::Apis::AlloydbV1beta::TimeBasedRetention

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

A time based retention policy specifies that all backups within a certain time period should be retained.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeBasedRetention

Returns a new instance of TimeBasedRetention.



5583
5584
5585
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#retention_periodString

The retention period. Corresponds to the JSON property retentionPeriod

Returns:

  • (String)


5581
5582
5583
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5581

def retention_period
  @retention_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5588
5589
5590
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5588

def update!(**args)
  @retention_period = args[:retention_period] if args.key?(:retention_period)
end