Class: Google::Apis::AlloydbV1beta::UpgradeClusterResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

UpgradeClusterResponse contains the response for upgrade cluster operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeClusterResponse

Returns a new instance of UpgradeClusterResponse.



5745
5746
5747
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_upgrade_detailsArray<Google::Apis::AlloydbV1beta::ClusterUpgradeDetails>

Array of upgrade details for the current cluster and all the secondary clusters associated with this cluster. Corresponds to the JSON property clusterUpgradeDetails



5732
5733
5734
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5732

def cluster_upgrade_details
  @cluster_upgrade_details
end

#messageString

A user friendly message summarising the upgrade operation details and the next steps for the user if there is any. Corresponds to the JSON property message

Returns:

  • (String)


5738
5739
5740
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5738

def message
  @message
end

#statusString

Status of upgrade operation. Corresponds to the JSON property status

Returns:

  • (String)


5743
5744
5745
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5743

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5750
5751
5752
5753
5754
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5750

def update!(**args)
  @cluster_upgrade_details = args[:cluster_upgrade_details] if args.key?(:cluster_upgrade_details)
  @message = args[:message] if args.key?(:message)
  @status = args[:status] if args.key?(:status)
end