Class: Google::Apis::AlloydbV1beta::BackupDrEnabledWindow
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::BackupDrEnabledWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Information about a single window when BackupDR was enabled for this cluster.
Instance Attribute Summary collapse
-
#automated_backup_previously_enabled ⇒ Boolean
(also: #automated_backup_previously_enabled?)
Whether automated backup was previously enabled prior to enabling BackupDR protection for this cluster.
-
#backup_plan_association ⇒ String
The BackupPlanAssociation resource that was used to enable BackupDR protection for this cluster.
-
#continuous_backup_previous_recovery_window_days ⇒ Fixnum
The retention set for the continuous backup that was previously enabled prior to enabling BackupDR protection for this cluster.
-
#continuous_backup_previously_enabled ⇒ Boolean
(also: #continuous_backup_previously_enabled?)
Whether continuous backup was previously enabled prior to enabling BackupDR protection for this cluster.
-
#continuous_backup_previously_enabled_time ⇒ String
The time when continuous backup was previously enabled prior to enabling BackupDR protection for this cluster.
-
#data_source ⇒ String
The DataSource resource that represents the cluster in BackupDR.
-
#disabled_time ⇒ String
Time when the BackupDR protection for this cluster was disabled.
-
#enabled_time ⇒ String
Time when the BackupDR protection for this cluster was enabled.
-
#log_retention_period ⇒ String
The retention period for logs generated by BackupDR for this cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupDrEnabledWindow
constructor
A new instance of BackupDrEnabledWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupDrEnabledWindow
Returns a new instance of BackupDrEnabledWindow.
420 421 422 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 420 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automated_backup_previously_enabled ⇒ Boolean Also known as: automated_backup_previously_enabled?
Whether automated backup was previously enabled prior to enabling BackupDR
protection for this cluster.
Corresponds to the JSON property automatedBackupPreviouslyEnabled
371 372 373 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 371 def automated_backup_previously_enabled @automated_backup_previously_enabled end |
#backup_plan_association ⇒ String
The BackupPlanAssociation resource that was used to enable BackupDR protection
for this cluster.
Corresponds to the JSON property backupPlanAssociation
378 379 380 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 378 def backup_plan_association @backup_plan_association end |
#continuous_backup_previous_recovery_window_days ⇒ Fixnum
The retention set for the continuous backup that was previously enabled prior
to enabling BackupDR protection for this cluster.
Corresponds to the JSON property continuousBackupPreviousRecoveryWindowDays
384 385 386 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 384 def continuous_backup_previous_recovery_window_days @continuous_backup_previous_recovery_window_days end |
#continuous_backup_previously_enabled ⇒ Boolean Also known as: continuous_backup_previously_enabled?
Whether continuous backup was previously enabled prior to enabling BackupDR
protection for this cluster.
Corresponds to the JSON property continuousBackupPreviouslyEnabled
390 391 392 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 390 def continuous_backup_previously_enabled @continuous_backup_previously_enabled end |
#continuous_backup_previously_enabled_time ⇒ String
The time when continuous backup was previously enabled prior to enabling
BackupDR protection for this cluster.
Corresponds to the JSON property continuousBackupPreviouslyEnabledTime
397 398 399 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 397 def continuous_backup_previously_enabled_time @continuous_backup_previously_enabled_time end |
#data_source ⇒ String
The DataSource resource that represents the cluster in BackupDR.
Corresponds to the JSON property dataSource
402 403 404 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 402 def data_source @data_source end |
#disabled_time ⇒ String
Time when the BackupDR protection for this cluster was disabled. This field
will be empty if this BackupDR window is the current_window.
Corresponds to the JSON property disabledTime
408 409 410 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 408 def disabled_time @disabled_time end |
#enabled_time ⇒ String
Time when the BackupDR protection for this cluster was enabled.
Corresponds to the JSON property enabledTime
413 414 415 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 413 def enabled_time @enabled_time end |
#log_retention_period ⇒ String
The retention period for logs generated by BackupDR for this cluster.
Corresponds to the JSON property logRetentionPeriod
418 419 420 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 418 def log_retention_period @log_retention_period end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 425 def update!(**args) @automated_backup_previously_enabled = args[:automated_backup_previously_enabled] if args.key?(:automated_backup_previously_enabled) @backup_plan_association = args[:backup_plan_association] if args.key?(:backup_plan_association) @continuous_backup_previous_recovery_window_days = args[:continuous_backup_previous_recovery_window_days] if args.key?(:continuous_backup_previous_recovery_window_days) @continuous_backup_previously_enabled = args[:continuous_backup_previously_enabled] if args.key?(:continuous_backup_previously_enabled) @continuous_backup_previously_enabled_time = args[:continuous_backup_previously_enabled_time] if args.key?(:continuous_backup_previously_enabled_time) @data_source = args[:data_source] if args.key?(:data_source) @disabled_time = args[:disabled_time] if args.key?(:disabled_time) @enabled_time = args[:enabled_time] if args.key?(:enabled_time) @log_retention_period = args[:log_retention_period] if args.key?(:log_retention_period) end |