Class: Google::Apis::AlloydbV1beta::BackupSource
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::BackupSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Message describing a BackupSource.
Instance Attribute Summary collapse
-
#backup_name ⇒ String
Required.
-
#backup_uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupSource
constructor
A new instance of BackupSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupSource
Returns a new instance of BackupSource.
533 534 535 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_name ⇒ String
Required. The name of the backup resource with the format: * projects/project
/locations/region/backups/backup_id
Corresponds to the JSON property backupName
524 525 526 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 524 def backup_name @backup_name end |
#backup_uid ⇒ String
Output only. The system-generated UID of the backup which was used to create
this resource. The UID is generated when the backup is created, and it is
retained until the backup is deleted.
Corresponds to the JSON property backupUid
531 532 533 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 531 def backup_uid @backup_uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
538 539 540 541 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 538 def update!(**args) @backup_name = args[:backup_name] if args.key?(:backup_name) @backup_uid = args[:backup_uid] if args.key?(:backup_uid) end |