Class: Google::Apis::AlloydbV1beta::ClusterUpgradeDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Upgrade details of a cluster. This cluster can be primary or secondary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpgradeDetails

Returns a new instance of ClusterUpgradeDetails.



937
938
939
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_typeString

Cluster type which can either be primary or secondary. Corresponds to the JSON property clusterType

Returns:

  • (String)


908
909
910
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 908

def cluster_type
  @cluster_type
end

#database_versionString

Database version of the cluster after the upgrade operation. This will be the target version if the upgrade was successful otherwise it remains the same as that before the upgrade operation. Corresponds to the JSON property databaseVersion

Returns:

  • (String)


915
916
917
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 915

def database_version
  @database_version
end

#instance_upgrade_detailsArray<Google::Apis::AlloydbV1beta::InstanceUpgradeDetails>

Upgrade details of the instances directly associated with this cluster. Corresponds to the JSON property instanceUpgradeDetails



920
921
922
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 920

def instance_upgrade_details
  @instance_upgrade_details
end

#nameString

Normalized name of the cluster Corresponds to the JSON property name

Returns:

  • (String)


925
926
927
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 925

def name
  @name
end

#stage_infoArray<Google::Apis::AlloydbV1beta::StageInfo>

Array containing stage info associated with this cluster. Corresponds to the JSON property stageInfo



930
931
932
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 930

def stage_info
  @stage_info
end

#upgrade_statusString

Upgrade status of the cluster. Corresponds to the JSON property upgradeStatus

Returns:

  • (String)


935
936
937
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 935

def upgrade_status
  @upgrade_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



942
943
944
945
946
947
948
949
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 942

def update!(**args)
  @cluster_type = args[:cluster_type] if args.key?(:cluster_type)
  @database_version = args[:database_version] if args.key?(:database_version)
  @instance_upgrade_details = args[:instance_upgrade_details] if args.key?(:instance_upgrade_details)
  @name = args[:name] if args.key?(:name)
  @stage_info = args[:stage_info] if args.key?(:stage_info)
  @upgrade_status = args[:upgrade_status] if args.key?(:upgrade_status)
end