Class: Google::Apis::AlloydbV1beta::ContinuousBackupConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::ContinuousBackupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
ContinuousBackupConfig describes the continuous backups recovery configurations of a cluster.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether ContinuousBackup is enabled.
-
#encryption_config ⇒ Google::Apis::AlloydbV1beta::EncryptionConfig
EncryptionConfig describes the encryption config of a cluster or a backup that is encrypted with a CMEK (customer-managed encryption key).
-
#recovery_window_days ⇒ Fixnum
The number of days that are eligible to restore from using PITR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContinuousBackupConfig
constructor
A new instance of ContinuousBackupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContinuousBackupConfig
Returns a new instance of ContinuousBackupConfig.
1112 1113 1114 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1112 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Whether ContinuousBackup is enabled.
Corresponds to the JSON property enabled
1096 1097 1098 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1096 def enabled @enabled end |
#encryption_config ⇒ Google::Apis::AlloydbV1beta::EncryptionConfig
EncryptionConfig describes the encryption config of a cluster or a backup that
is encrypted with a CMEK (customer-managed encryption key).
Corresponds to the JSON property encryptionConfig
1103 1104 1105 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1103 def encryption_config @encryption_config end |
#recovery_window_days ⇒ Fixnum
The number of days that are eligible to restore from using PITR. To support
the entire recovery window, backups and logs are retained for one day more
than the recovery window. If not set, defaults to 14 days.
Corresponds to the JSON property recoveryWindowDays
1110 1111 1112 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1110 def recovery_window_days @recovery_window_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1117 1118 1119 1120 1121 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1117 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @recovery_window_days = args[:recovery_window_days] if args.key?(:recovery_window_days) end |