Class: Google::Apis::AlloydbV1beta::ContinuousBackupInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

ContinuousBackupInfo describes the continuous backup properties of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContinuousBackupInfo

Returns a new instance of ContinuousBackupInfo.



1110
1111
1112
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#earliest_restorable_timeString

Output only. The earliest restorable time that can be restored to. If continuous backups and recovery was recently enabled, the earliest restorable time is the creation time of the earliest eligible backup within this cluster' s continuous backup recovery window. After a cluster has had continuous backups enabled for the duration of its recovery window, the earliest restorable time becomes "now minus the recovery window". For example, assuming a point in time recovery is attempted at 04/16/2025 3:23:00PM with a 14d recovery window, the earliest restorable time would be 04/02/2025 3:23:00PM. This field is only visible if the CLUSTER_VIEW_CONTINUOUS_BACKUP cluster view is provided. Corresponds to the JSON property earliestRestorableTime

Returns:

  • (String)


1092
1093
1094
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1092

def earliest_restorable_time
  @earliest_restorable_time
end

#enabled_timeString

Output only. When ContinuousBackup was most recently enabled. Set to null if ContinuousBackup is not enabled. Corresponds to the JSON property enabledTime

Returns:

  • (String)


1098
1099
1100
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1098

def enabled_time
  @enabled_time
end

#encryption_infoGoogle::Apis::AlloydbV1beta::EncryptionInfo

EncryptionInfo describes the encryption information of a cluster or a backup. Corresponds to the JSON property encryptionInfo



1103
1104
1105
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1103

def encryption_info
  @encryption_info
end

#scheduleArray<String>

Output only. Days of the week on which a continuous backup is taken. Corresponds to the JSON property schedule

Returns:

  • (Array<String>)


1108
1109
1110
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1108

def schedule
  @schedule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1115
1116
1117
1118
1119
1120
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1115

def update!(**args)
  @earliest_restorable_time = args[:earliest_restorable_time] if args.key?(:earliest_restorable_time)
  @enabled_time = args[:enabled_time] if args.key?(:enabled_time)
  @encryption_info = args[:encryption_info] if args.key?(:encryption_info)
  @schedule = args[:schedule] if args.key?(:schedule)
end