Class: Google::Apis::AlloydbV1beta::ContinuousBackupSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Message describing a ContinuousBackupSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContinuousBackupSource

Returns a new instance of ContinuousBackupSource.



1145
1146
1147
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Required. The source cluster from which to restore. This cluster must have continuous backup enabled for this operation to succeed. For the required format, see the comment on the Cluster.name field. Corresponds to the JSON property cluster

Returns:

  • (String)


1138
1139
1140
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1138

def cluster
  @cluster
end

#point_in_timeString

Required. The point in time to restore to. Corresponds to the JSON property pointInTime

Returns:

  • (String)


1143
1144
1145
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1143

def point_in_time
  @point_in_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1150
1151
1152
1153
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1150

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @point_in_time = args[:point_in_time] if args.key?(:point_in_time)
end