Class: Google::Apis::AlloydbV1beta::CsvImportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Options for importing data in CSV format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CsvImportOptions

Returns a new instance of CsvImportOptions.



1248
1249
1250
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<String>

Optional. The columns to which CSV data is imported. If not specified, all columns of the database table are loaded with CSV data. Corresponds to the JSON property columns

Returns:

  • (Array<String>)


1220
1221
1222
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1220

def columns
  @columns
end

#escape_characterString

Optional. Specifies the character that should appear before a data character that needs to be escaped. The default is same as quote character. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property escapeCharacter

Returns:

  • (String)


1227
1228
1229
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1227

def escape_character
  @escape_character
end

#field_delimiterString

Optional. Specifies the character that separates columns within each row (line) of the file. The default is comma. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property fieldDelimiter

Returns:

  • (String)


1234
1235
1236
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1234

def field_delimiter
  @field_delimiter
end

#quote_characterString

Optional. Specifies the quoting character to be used when a data value is quoted. The default is double-quote. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property quoteCharacter

Returns:

  • (String)


1241
1242
1243
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1241

def quote_character
  @quote_character
end

#tableString

Required. The database table to import CSV file into. Corresponds to the JSON property table

Returns:

  • (String)


1246
1247
1248
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1246

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1253
1254
1255
1256
1257
1258
1259
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1253

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @escape_character = args[:escape_character] if args.key?(:escape_character)
  @field_delimiter = args[:field_delimiter] if args.key?(:field_delimiter)
  @quote_character = args[:quote_character] if args.key?(:quote_character)
  @table = args[:table] if args.key?(:table)
end