Class: Google::Apis::AlloydbV1beta::DataplexConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::DataplexConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Configuration for Dataplex integration.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Dataplex is enabled by default for resources such as clusters and instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataplexConfig
constructor
A new instance of DataplexConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataplexConfig
Returns a new instance of DataplexConfig.
1326 1327 1328 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1326 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Dataplex is enabled by default for resources such as clusters and instances.
This flag controls the integration of AlloyDB PG resources (like databases,
schemas, and tables) with Dataplex."
Corresponds to the JSON property enabled
1323 1324 1325 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1323 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1331 1332 1333 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1331 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |