Class: Google::Apis::AlloydbV1beta::DenyMaintenancePeriod

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

DenyMaintenancePeriod definition. Excepting emergencies, maintenance will not be scheduled to start within this deny period. The start_date must be less than the end_date.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DenyMaintenancePeriod

Returns a new instance of DenyMaintenancePeriod.



1354
1355
1356
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dateGoogle::Apis::AlloydbV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



1333
1334
1335
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1333

def end_date
  @end_date
end

#start_dateGoogle::Apis::AlloydbV1beta::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



1345
1346
1347
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1345

def start_date
  @start_date
end

#timeGoogle::Apis::AlloydbV1beta::GoogleTypeTimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property time



1352
1353
1354
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1352

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1359
1360
1361
1362
1363
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1359

def update!(**args)
  @end_date = args[:end_date] if args.key?(:end_date)
  @start_date = args[:start_date] if args.key?(:start_date)
  @time = args[:time] if args.key?(:time)
end