Class: Google::Apis::AlloydbV1beta::ExportClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Export cluster request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportClusterRequest

Returns a new instance of ExportClusterRequest.



1575
1576
1577
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#csv_export_optionsGoogle::Apis::AlloydbV1beta::CsvExportOptions

Options for exporting data in CSV format. Corresponds to the JSON property csvExportOptions



1556
1557
1558
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1556

def csv_export_options
  @csv_export_options
end

#databaseString

Required. Name of the database where the export command will be executed. Note

  • Value provided should be the same as expected from SELECT current_database() ; and NOT as a resource reference. Corresponds to the JSON property database

Returns:

  • (String)


1563
1564
1565
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1563

def database
  @database
end

#gcs_destinationGoogle::Apis::AlloydbV1beta::GcsDestination

Destination for Export. Export will be done to cloud storage. Corresponds to the JSON property gcsDestination



1568
1569
1570
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1568

def gcs_destination
  @gcs_destination
end

#sql_export_optionsGoogle::Apis::AlloydbV1beta::SqlExportOptions

Options for exporting data in SQL format. Corresponds to the JSON property sqlExportOptions



1573
1574
1575
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1573

def sql_export_options
  @sql_export_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1580
1581
1582
1583
1584
1585
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1580

def update!(**args)
  @csv_export_options = args[:csv_export_options] if args.key?(:csv_export_options)
  @database = args[:database] if args.key?(:database)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @sql_export_options = args[:sql_export_options] if args.key?(:sql_export_options)
end