Class: Google::Apis::AlloydbV1beta::FailoverInstanceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Message for triggering failover on an Instance

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FailoverInstanceRequest

Returns a new instance of FailoverInstanceRequest.



1614
1615
1616
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


1604
1605
1606
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1604

def request_id
  @request_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1611
1612
1613
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1611

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1619
1620
1621
1622
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1619

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end