Class: Google::Apis::AlloydbV1beta::GeminiClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Deprecated and unused. This message will be removed in the near future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeminiClusterConfig

Returns a new instance of GeminiClusterConfig.



1676
1677
1678
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitledBoolean Also known as: entitled?

Output only. Deprecated and unused. This field will be removed in the near future. Corresponds to the JSON property entitled

Returns:

  • (Boolean)


1673
1674
1675
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1673

def entitled
  @entitled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1681
1682
1683
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1681

def update!(**args)
  @entitled = args[:entitled] if args.key?(:entitled)
end