Class: Google::Apis::AlloydbV1beta::GeminiInstanceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Deprecated and unused. This message will be removed in the near future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeminiInstanceConfig

Returns a new instance of GeminiInstanceConfig.



1710
1711
1712
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitledBoolean Also known as: entitled?

Output only. Deprecated and unused. This field will be removed in the near future. Corresponds to the JSON property entitled

Returns:

  • (Boolean)


1707
1708
1709
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1707

def entitled
  @entitled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1715
1716
1717
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1715

def update!(**args)
  @entitled = args[:entitled] if args.key?(:entitled)
end