Class: Google::Apis::AlloydbV1beta::GoogleTypeTimeOfDay
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::GoogleTypeTimeOfDay
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Instance Attribute Summary collapse
-
#hours ⇒ Fixnum
Hours of a day in 24 hour format.
-
#minutes ⇒ Fixnum
Minutes of an hour.
-
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds.
-
#seconds ⇒ Fixnum
Seconds of a minute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeTimeOfDay
constructor
A new instance of GoogleTypeTimeOfDay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeTimeOfDay
Returns a new instance of GoogleTypeTimeOfDay.
1901 1902 1903 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hours ⇒ Fixnum
Hours of a day in 24 hour format. Must be greater than or equal to 0 and
typically must be less than or equal to 23. An API may choose to allow the
value "24:00:00" for scenarios like business closing time.
Corresponds to the JSON property hours
1880 1881 1882 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1880 def hours @hours end |
#minutes ⇒ Fixnum
Minutes of an hour. Must be greater than or equal to 0 and less than or equal
to 59.
Corresponds to the JSON property minutes
1886 1887 1888 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1886 def minutes @minutes end |
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and
less than or equal to 999,999,999.
Corresponds to the JSON property nanos
1892 1893 1894 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1892 def nanos @nanos end |
#seconds ⇒ Fixnum
Seconds of a minute. Must be greater than or equal to 0 and typically must be
less than or equal to 59. An API may allow the value 60 if it allows leap-
seconds.
Corresponds to the JSON property seconds
1899 1900 1901 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1899 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1906 1907 1908 1909 1910 1911 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1906 def update!(**args) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |