Class: Google::Apis::AlloydbV1beta::GoogleTypeTimeOfDay
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::GoogleTypeTimeOfDay
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Instance Attribute Summary collapse
-
#hours ⇒ Fixnum
Hours of a day in 24 hour format.
-
#minutes ⇒ Fixnum
Minutes of an hour.
-
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds.
-
#seconds ⇒ Fixnum
Seconds of a minute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeTimeOfDay
constructor
A new instance of GoogleTypeTimeOfDay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeTimeOfDay
Returns a new instance of GoogleTypeTimeOfDay.
1865 1866 1867 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1865 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hours ⇒ Fixnum
Hours of a day in 24 hour format. Must be greater than or equal to 0 and
typically must be less than or equal to 23. An API may choose to allow the
value "24:00:00" for scenarios like business closing time.
Corresponds to the JSON property hours
1844 1845 1846 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1844 def hours @hours end |
#minutes ⇒ Fixnum
Minutes of an hour. Must be greater than or equal to 0 and less than or equal
to 59.
Corresponds to the JSON property minutes
1850 1851 1852 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1850 def minutes @minutes end |
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and
less than or equal to 999,999,999.
Corresponds to the JSON property nanos
1856 1857 1858 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1856 def nanos @nanos end |
#seconds ⇒ Fixnum
Seconds of a minute. Must be greater than or equal to 0 and typically must be
less than or equal to 59. An API may allow the value 60 if it allows leap-
seconds.
Corresponds to the JSON property seconds
1863 1864 1865 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1863 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1870 1871 1872 1873 1874 1875 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 1870 def update!(**args) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |