Class: Google::Apis::AlloydbV1beta::InstanceNetworkConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::InstanceNetworkConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Metadata related to instance-level network configuration.
Instance Attribute Summary collapse
-
#allocated_ip_range_override ⇒ String
Optional.
-
#authorized_external_networks ⇒ Array<Google::Apis::AlloydbV1beta::AuthorizedNetwork>
Optional.
-
#enable_outbound_public_ip ⇒ Boolean
(also: #enable_outbound_public_ip?)
Optional.
-
#enable_public_ip ⇒ Boolean
(also: #enable_public_ip?)
Optional.
-
#network ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceNetworkConfig
constructor
A new instance of InstanceNetworkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceNetworkConfig
Returns a new instance of InstanceNetworkConfig.
2298 2299 2300 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_ip_range_override ⇒ String
Optional. Name of the allocated IP range for the private IP AlloyDB instance,
for example: "google-managed-services-default". If set, the instance IPs will
be created from this allocated range and will override the IP range used by
the parent cluster. The range name must comply with RFC 1035. Specifically, the name must be 1-63
characters long and match the regular expression a-z?.
Corresponds to the JSON property allocatedIpRangeOverride
2270 2271 2272 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2270 def allocated_ip_range_override @allocated_ip_range_override end |
#authorized_external_networks ⇒ Array<Google::Apis::AlloydbV1beta::AuthorizedNetwork>
Optional. A list of external network authorized to access this instance.
Corresponds to the JSON property authorizedExternalNetworks
2275 2276 2277 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2275 def @authorized_external_networks end |
#enable_outbound_public_ip ⇒ Boolean Also known as: enable_outbound_public_ip?
Optional. Enabling an outbound public IP address to support a database server
sending requests out into the internet.
Corresponds to the JSON property enableOutboundPublicIp
2281 2282 2283 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2281 def enable_outbound_public_ip @enable_outbound_public_ip end |
#enable_public_ip ⇒ Boolean Also known as: enable_public_ip?
Optional. Enabling public ip for the instance.
Corresponds to the JSON property enablePublicIp
2287 2288 2289 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2287 def enable_public_ip @enable_public_ip end |
#network ⇒ String
Output only. The resource link for the VPC network in which instance resources
are created and from which they are accessible via Private IP. This will be
the same value as the parent cluster's network. It is specified in the form: //
projects/project_number/global/networks/network_id`.
Corresponds to the JSON propertynetwork`
2296 2297 2298 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2296 def network @network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2303 2304 2305 2306 2307 2308 2309 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2303 def update!(**args) @allocated_ip_range_override = args[:allocated_ip_range_override] if args.key?(:allocated_ip_range_override) @authorized_external_networks = args[:authorized_external_networks] if args.key?(:authorized_external_networks) @enable_outbound_public_ip = args[:enable_outbound_public_ip] if args.key?(:enable_outbound_public_ip) @enable_public_ip = args[:enable_public_ip] if args.key?(:enable_public_ip) @network = args[:network] if args.key?(:network) end |