Class: Google::Apis::AlloydbV1beta::IntegerRestrictions
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::IntegerRestrictions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Restrictions on INTEGER type values.
Instance Attribute Summary collapse
-
#max_value ⇒ Fixnum
The maximum value that can be specified, if applicable.
-
#min_value ⇒ Fixnum
The minimum value that can be specified, if applicable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IntegerRestrictions
constructor
A new instance of IntegerRestrictions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IntegerRestrictions
Returns a new instance of IntegerRestrictions.
2332 2333 2334 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2332 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_value ⇒ Fixnum
The maximum value that can be specified, if applicable.
Corresponds to the JSON property maxValue
2325 2326 2327 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2325 def max_value @max_value end |
#min_value ⇒ Fixnum
The minimum value that can be specified, if applicable.
Corresponds to the JSON property minValue
2330 2331 2332 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2330 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2337 2338 2339 2340 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2337 def update!(**args) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |