Class: Google::Apis::AlloydbV1beta::MaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

MaintenanceWindow specifies a preferred day and time for maintenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceWindow

Returns a new instance of MaintenanceWindow.



2678
2679
2680
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc. Corresponds to the JSON property day

Returns:

  • (String)


2669
2670
2671
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2669

def day
  @day
end

#start_timeGoogle::Apis::AlloydbV1beta::GoogleTypeTimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



2676
2677
2678
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2676

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2683
2684
2685
2686
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2683

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @start_time = args[:start_time] if args.key?(:start_time)
end