Class: Google::Apis::AlloydbV1beta::MaintenanceWindow
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::MaintenanceWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
MaintenanceWindow specifies a preferred day and time for maintenance.
Instance Attribute Summary collapse
-
#day ⇒ String
Preferred day of the week for maintenance, e.g.
-
#start_time ⇒ Google::Apis::AlloydbV1beta::GoogleTypeTimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaintenanceWindow
constructor
A new instance of MaintenanceWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaintenanceWindow
Returns a new instance of MaintenanceWindow.
2653 2654 2655 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc.
Corresponds to the JSON property day
2644 2645 2646 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2644 def day @day end |
#start_time ⇒ Google::Apis::AlloydbV1beta::GoogleTypeTimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
2651 2652 2653 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2651 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2658 2659 2660 2661 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2658 def update!(**args) @day = args[:day] if args.key?(:day) @start_time = args[:start_time] if args.key?(:start_time) end |