Class: Google::Apis::AlloydbV1beta::ObservabilityInstanceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Observability Instance specific configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObservabilityInstanceConfig

Returns a new instance of ObservabilityInstanceConfig.



2879
2880
2881
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assistive_experiences_enabledBoolean Also known as: assistive_experiences_enabled?

Whether assistive experiences are enabled for this AlloyDB instance. Corresponds to the JSON property assistiveExperiencesEnabled

Returns:

  • (Boolean)


2807
2808
2809
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2807

def assistive_experiences_enabled
  @assistive_experiences_enabled
end

#enabledBoolean Also known as: enabled?

Observability feature status for an instance. This flag is turned "off" by default. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2814
2815
2816
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2814

def enabled
  @enabled
end

#max_query_string_lengthFixnum

Query string length. The default value is 10k. Corresponds to the JSON property maxQueryStringLength

Returns:

  • (Fixnum)


2820
2821
2822
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2820

def max_query_string_length
  @max_query_string_length
end

#preserve_commentsBoolean Also known as: preserve_comments?

Preserve comments in query string for an instance. This flag is turned "off" by default. Corresponds to the JSON property preserveComments

Returns:

  • (Boolean)


2826
2827
2828
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2826

def preserve_comments
  @preserve_comments
end

#query_plans_per_minuteFixnum

Number of query execution plans captured by Insights per minute for all queries combined. The default value is 200. Any integer between 0 to 200 is considered valid. Corresponds to the JSON property queryPlansPerMinute

Returns:

  • (Fixnum)


2834
2835
2836
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2834

def query_plans_per_minute
  @query_plans_per_minute
end

#record_application_tagsBoolean Also known as: record_application_tags?

Record application tags for an instance. This flag is turned "off" by default. Corresponds to the JSON property recordApplicationTags

Returns:

  • (Boolean)


2839
2840
2841
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2839

def record_application_tags
  @record_application_tags
end

#track_active_queriesBoolean Also known as: track_active_queries?

Track actively running queries on the instance. If not set, this flag is "off" by default. Corresponds to the JSON property trackActiveQueries

Returns:

  • (Boolean)


2846
2847
2848
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2846

def track_active_queries
  @track_active_queries
end

#track_active_query_planBoolean Also known as: track_active_query_plan?

Indicates whether to track active query plans for an instance. If not set, the default value is "off". Can only be enabled if track_active_queries is enabled. Corresponds to the JSON property trackActiveQueryPlan

Returns:

  • (Boolean)


2853
2854
2855
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2853

def track_active_query_plan
  @track_active_query_plan
end

#track_client_addressBoolean Also known as: track_client_address?

Track client address for an instance. If not set, default value is "off". Corresponds to the JSON property trackClientAddress

Returns:

  • (Boolean)


2859
2860
2861
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2859

def track_client_address
  @track_client_address
end

#track_wait_event_typesBoolean Also known as: track_wait_event_types?

Output only. Track wait event types during query execution for an instance. This flag is turned "on" by default but tracking is enabled only after observability enabled flag is also turned on. This is read-only flag and only modifiable by internal API. Corresponds to the JSON property trackWaitEventTypes

Returns:

  • (Boolean)


2868
2869
2870
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2868

def track_wait_event_types
  @track_wait_event_types
end

#track_wait_eventsBoolean Also known as: track_wait_events?

Track wait events during query execution for an instance. This flag is turned " on" by default but tracking is enabled only after observability enabled flag is also turned on. Corresponds to the JSON property trackWaitEvents

Returns:

  • (Boolean)


2876
2877
2878
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2876

def track_wait_events
  @track_wait_events
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 2884

def update!(**args)
  @assistive_experiences_enabled = args[:assistive_experiences_enabled] if args.key?(:assistive_experiences_enabled)
  @enabled = args[:enabled] if args.key?(:enabled)
  @max_query_string_length = args[:max_query_string_length] if args.key?(:max_query_string_length)
  @preserve_comments = args[:preserve_comments] if args.key?(:preserve_comments)
  @query_plans_per_minute = args[:query_plans_per_minute] if args.key?(:query_plans_per_minute)
  @record_application_tags = args[:record_application_tags] if args.key?(:record_application_tags)
  @track_active_queries = args[:track_active_queries] if args.key?(:track_active_queries)
  @track_active_query_plan = args[:track_active_query_plan] if args.key?(:track_active_query_plan)
  @track_client_address = args[:track_client_address] if args.key?(:track_client_address)
  @track_wait_event_types = args[:track_wait_event_types] if args.key?(:track_wait_event_types)
  @track_wait_events = args[:track_wait_events] if args.key?(:track_wait_events)
end