Class: Google::Apis::AlloydbV1beta::PrimaryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Configuration for the primary cluster. It has the list of clusters that are replicating from this cluster. This should be set if and only if the cluster is of type PRIMARY.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrimaryConfig

Returns a new instance of PrimaryConfig.



3078
3079
3080
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secondary_cluster_namesArray<String>

Output only. Names of the clusters that are replicating from this cluster. Corresponds to the JSON property secondaryClusterNames

Returns:

  • (Array<String>)


3076
3077
3078
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3076

def secondary_cluster_names
  @secondary_cluster_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3083
3084
3085
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3083

def update!(**args)
  @secondary_cluster_names = args[:secondary_cluster_names] if args.key?(:secondary_cluster_names)
end