Class: Google::Apis::AlloydbV1beta::PromoteClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Message for promoting a Cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PromoteClusterRequest

Returns a new instance of PromoteClusterRequest.



3105
3106
3107
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The current etag of the Cluster. If an etag is provided and does not match the current etag of the Cluster, deletion will be blocked and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


3072
3073
3074
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3072

def etag
  @etag
end

#failoverBoolean Also known as: failover?

Optional. If set, the promote operation will attempt to recreate the original primary cluster as a secondary cluster when it comes back online. Otherwise, the promoted cluster will be a standalone cluster. Currently only supported when there is a single secondary cluster. Corresponds to the JSON property failover

Returns:

  • (Boolean)


3080
3081
3082
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3080

def failover
  @failover
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


3095
3096
3097
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3095

def request_id
  @request_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


3102
3103
3104
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3102

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3110
3111
3112
3113
3114
3115
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3110

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @failover = args[:failover] if args.key?(:failover)
  @request_id = args[:request_id] if args.key?(:request_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end