Class: Google::Apis::AlloydbV1beta::PscConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

PscConfig contains PSC related configuration at a cluster level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscConfig

Returns a new instance of PscConfig.



3211
3212
3213
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#psc_enabledBoolean Also known as: psc_enabled?

Optional. Create an instance that allows connections from Private Service Connect endpoints to the instance. Corresponds to the JSON property pscEnabled

Returns:

  • (Boolean)


3202
3203
3204
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3202

def psc_enabled
  @psc_enabled
end

#service_owned_project_numberFixnum

Output only. The project number that needs to be allowlisted on the network attachment to enable outbound connectivity. Corresponds to the JSON property serviceOwnedProjectNumber

Returns:

  • (Fixnum)


3209
3210
3211
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3209

def service_owned_project_number
  @service_owned_project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3216
3217
3218
3219
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3216

def update!(**args)
  @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled)
  @service_owned_project_number = args[:service_owned_project_number] if args.key?(:service_owned_project_number)
end