Class: Google::Apis::AlloydbV1beta::RestoreClusterRequest
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::RestoreClusterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Message for restoring a Cluster from a backup or another cluster at a given point in time. NEXT_ID: 11
Instance Attribute Summary collapse
-
#backup_source ⇒ Google::Apis::AlloydbV1beta::BackupSource
Message describing a BackupSource.
-
#backupdr_backup_source ⇒ Google::Apis::AlloydbV1beta::BackupDrBackupSource
Message describing a BackupDrBackupSource.
-
#backupdr_pitr_source ⇒ Google::Apis::AlloydbV1beta::BackupDrPitrSource
Message describing a BackupDrPitrSource.
-
#cluster ⇒ Google::Apis::AlloydbV1beta::Cluster
A cluster is a collection of regional AlloyDB resources.
-
#cluster_id ⇒ String
Required.
-
#continuous_backup_source ⇒ Google::Apis::AlloydbV1beta::ContinuousBackupSource
Message describing a ContinuousBackupSource.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreClusterRequest
constructor
A new instance of RestoreClusterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreClusterRequest
Returns a new instance of RestoreClusterRequest.
3610 3611 3612 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3610 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_source ⇒ Google::Apis::AlloydbV1beta::BackupSource
Message describing a BackupSource.
Corresponds to the JSON property backupSource
3559 3560 3561 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3559 def backup_source @backup_source end |
#backupdr_backup_source ⇒ Google::Apis::AlloydbV1beta::BackupDrBackupSource
Message describing a BackupDrBackupSource.
Corresponds to the JSON property backupdrBackupSource
3564 3565 3566 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3564 def backupdr_backup_source @backupdr_backup_source end |
#backupdr_pitr_source ⇒ Google::Apis::AlloydbV1beta::BackupDrPitrSource
Message describing a BackupDrPitrSource.
Corresponds to the JSON property backupdrPitrSource
3569 3570 3571 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3569 def backupdr_pitr_source @backupdr_pitr_source end |
#cluster ⇒ Google::Apis::AlloydbV1beta::Cluster
A cluster is a collection of regional AlloyDB resources. It can include a
primary instance and one or more read pool instances. All cluster resources
share a storage layer, which scales as needed.
Corresponds to the JSON property cluster
3576 3577 3578 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3576 def cluster @cluster end |
#cluster_id ⇒ String
Required. ID of the requesting object.
Corresponds to the JSON property clusterId
3581 3582 3583 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3581 def cluster_id @cluster_id end |
#continuous_backup_source ⇒ Google::Apis::AlloydbV1beta::ContinuousBackupSource
Message describing a ContinuousBackupSource.
Corresponds to the JSON property continuousBackupSource
3586 3587 3588 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3586 def continuous_backup_source @continuous_backup_source end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server ignores the
request if it has already been completed. The server guarantees that for at
least 60 minutes since the first request. For example, consider a situation
where you make an initial request and the request times out. If you make the
request again with the same request ID, the server can check if the original
operation with the same request ID was received, and if so, ignores the second
request. This prevents clients from accidentally creating duplicate
commitments. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
3600 3601 3602 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3600 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, performs request validation, for example, permission checks
and any other type of validation, but does not actually execute the create
request.
Corresponds to the JSON property validateOnly
3607 3608 3609 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3607 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3615 def update!(**args) @backup_source = args[:backup_source] if args.key?(:backup_source) @backupdr_backup_source = args[:backupdr_backup_source] if args.key?(:backupdr_backup_source) @backupdr_pitr_source = args[:backupdr_pitr_source] if args.key?(:backupdr_pitr_source) @cluster = args[:cluster] if args.key?(:cluster) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @continuous_backup_source = args[:continuous_backup_source] if args.key?(:continuous_backup_source) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |