Class: Google::Apis::AlloydbV1beta::RestoreClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Message for restoring a Cluster from a backup or another cluster at a given point in time. NEXT_ID: 11

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreClusterRequest

Returns a new instance of RestoreClusterRequest.



3550
3551
3552
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_sourceGoogle::Apis::AlloydbV1beta::BackupSource

Message describing a BackupSource. Corresponds to the JSON property backupSource



3499
3500
3501
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3499

def backup_source
  @backup_source
end

#backupdr_backup_sourceGoogle::Apis::AlloydbV1beta::BackupDrBackupSource

Message describing a BackupDrBackupSource. Corresponds to the JSON property backupdrBackupSource



3504
3505
3506
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3504

def backupdr_backup_source
  @backupdr_backup_source
end

#backupdr_pitr_sourceGoogle::Apis::AlloydbV1beta::BackupDrPitrSource

Message describing a BackupDrPitrSource. Corresponds to the JSON property backupdrPitrSource



3509
3510
3511
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3509

def backupdr_pitr_source
  @backupdr_pitr_source
end

#clusterGoogle::Apis::AlloydbV1beta::Cluster

A cluster is a collection of regional AlloyDB resources. It can include a primary instance and one or more read pool instances. All cluster resources share a storage layer, which scales as needed. Corresponds to the JSON property cluster



3516
3517
3518
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3516

def cluster
  @cluster
end

#cluster_idString

Required. ID of the requesting object. Corresponds to the JSON property clusterId

Returns:

  • (String)


3521
3522
3523
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3521

def cluster_id
  @cluster_id
end

#continuous_backup_sourceGoogle::Apis::AlloydbV1beta::ContinuousBackupSource

Message describing a ContinuousBackupSource. Corresponds to the JSON property continuousBackupSource



3526
3527
3528
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3526

def continuous_backup_source
  @continuous_backup_source
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


3540
3541
3542
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3540

def request_id
  @request_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


3547
3548
3549
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3547

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3555

def update!(**args)
  @backup_source = args[:backup_source] if args.key?(:backup_source)
  @backupdr_backup_source = args[:backupdr_backup_source] if args.key?(:backupdr_backup_source)
  @backupdr_pitr_source = args[:backupdr_pitr_source] if args.key?(:backupdr_pitr_source)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @continuous_backup_source = args[:continuous_backup_source] if args.key?(:continuous_backup_source)
  @request_id = args[:request_id] if args.key?(:request_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end