Class: Google::Apis::AlloydbV1beta::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
A schedule for the autoscaler.
Instance Attribute Summary collapse
-
#cron_expression ⇒ String
Cron expression for the triggering the schedule.
-
#description ⇒ String
Description of the schedule.
-
#disabled ⇒ Boolean
(also: #disabled?)
If true, the schedule is disabled.
-
#duration_sec ⇒ Fixnum
Duration of the schedule.
-
#min_node_count ⇒ Fixnum
Minimum number of nodes in while the schedule is active.
-
#name ⇒ String
Name of the schedule.
-
#time_zone ⇒ String
The location-based IANA time zone for interpreting the schedule's start time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
3642 3643 3644 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cron_expression ⇒ String
Cron expression for the triggering the schedule. See https://cloud.google.com/
compute/docs/autoscaler/scaling-schedules#cron_expressions for the syntax.
Corresponds to the JSON property cronExpression
3608 3609 3610 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3608 def cron_expression @cron_expression end |
#description ⇒ String
Description of the schedule.
Corresponds to the JSON property description
3613 3614 3615 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3613 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
If true, the schedule is disabled.
Corresponds to the JSON property disabled
3618 3619 3620 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3618 def disabled @disabled end |
#duration_sec ⇒ Fixnum
Duration of the schedule.
Corresponds to the JSON property durationSec
3624 3625 3626 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3624 def duration_sec @duration_sec end |
#min_node_count ⇒ Fixnum
Minimum number of nodes in while the schedule is active.
Corresponds to the JSON property minNodeCount
3629 3630 3631 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3629 def min_node_count @min_node_count end |
#name ⇒ String
Name of the schedule.
Corresponds to the JSON property name
3634 3635 3636 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3634 def name @name end |
#time_zone ⇒ String
The location-based IANA time zone for interpreting the schedule's start time.
If no time zone is provided, UTC is used by default.
Corresponds to the JSON property timeZone
3640 3641 3642 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3640 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3647 3648 3649 3650 3651 3652 3653 3654 3655 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3647 def update!(**args) @cron_expression = args[:cron_expression] if args.key?(:cron_expression) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @duration_sec = args[:duration_sec] if args.key?(:duration_sec) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) @name = args[:name] if args.key?(:name) @time_zone = args[:time_zone] if args.key?(:time_zone) end |