Class: Google::Apis::AlloydbV1beta::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
A schedule for the autoscaler.
Instance Attribute Summary collapse
-
#cron_expression ⇒ String
Cron expression for the triggering the schedule.
-
#description ⇒ String
Description of the schedule.
-
#disabled ⇒ Boolean
(also: #disabled?)
If true, the schedule is disabled.
-
#duration_sec ⇒ Fixnum
Duration of the schedule.
-
#min_node_count ⇒ Fixnum
Minimum number of nodes in while the schedule is active.
-
#name ⇒ String
Name of the schedule.
-
#time_zone ⇒ String
The location-based IANA time zone for interpreting the schedule's start time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
3617 3618 3619 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cron_expression ⇒ String
Cron expression for the triggering the schedule. See https://cloud.google.com/
compute/docs/autoscaler/scaling-schedules#cron_expressions for the syntax.
Corresponds to the JSON property cronExpression
3583 3584 3585 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3583 def cron_expression @cron_expression end |
#description ⇒ String
Description of the schedule.
Corresponds to the JSON property description
3588 3589 3590 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3588 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
If true, the schedule is disabled.
Corresponds to the JSON property disabled
3593 3594 3595 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3593 def disabled @disabled end |
#duration_sec ⇒ Fixnum
Duration of the schedule.
Corresponds to the JSON property durationSec
3599 3600 3601 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3599 def duration_sec @duration_sec end |
#min_node_count ⇒ Fixnum
Minimum number of nodes in while the schedule is active.
Corresponds to the JSON property minNodeCount
3604 3605 3606 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3604 def min_node_count @min_node_count end |
#name ⇒ String
Name of the schedule.
Corresponds to the JSON property name
3609 3610 3611 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3609 def name @name end |
#time_zone ⇒ String
The location-based IANA time zone for interpreting the schedule's start time.
If no time zone is provided, UTC is used by default.
Corresponds to the JSON property timeZone
3615 3616 3617 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3615 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3622 3623 3624 3625 3626 3627 3628 3629 3630 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3622 def update!(**args) @cron_expression = args[:cron_expression] if args.key?(:cron_expression) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @duration_sec = args[:duration_sec] if args.key?(:duration_sec) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) @name = args[:name] if args.key?(:name) @time_zone = args[:time_zone] if args.key?(:time_zone) end |