Class: Google::Apis::AlloydbV1beta::StageInfo
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::StageInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Stage information for different stages in the upgrade process.
Instance Attribute Summary collapse
-
#logs_url ⇒ String
logs_url is the URL for the logs associated with a stage if that stage has logs.
-
#stage ⇒ String
The stage.
-
#status ⇒ String
Status of the stage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StageInfo
constructor
A new instance of StageInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StageInfo
Returns a new instance of StageInfo.
3756 3757 3758 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#logs_url ⇒ String
logs_url is the URL for the logs associated with a stage if that stage has
logs. Right now, only three stages have logs: ALLOYDB_PRECHECK,
PG_UPGRADE_CHECK, PRIMARY_INSTANCE_UPGRADE.
Corresponds to the JSON property logsUrl
3744 3745 3746 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3744 def logs_url @logs_url end |
#stage ⇒ String
The stage.
Corresponds to the JSON property stage
3749 3750 3751 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3749 def stage @stage end |
#status ⇒ String
Status of the stage.
Corresponds to the JSON property status
3754 3755 3756 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3754 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3761 3762 3763 3764 3765 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3761 def update!(**args) @logs_url = args[:logs_url] if args.key?(:logs_url) @stage = args[:stage] if args.key?(:stage) @status = args[:status] if args.key?(:status) end |