Class: Google::Apis::AlloydbV1beta::Stats
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::Stats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Upgrade stats for read pool instances.
Instance Attribute Summary collapse
-
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
-
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
-
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
-
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stats
constructor
A new instance of Stats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stats
Returns a new instance of Stats.
3931 3932 3933 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
Corresponds to the JSON property failed
3914 3915 3916 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3914 def failed @failed end |
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
Corresponds to the JSON property notStarted
3919 3920 3921 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3919 def not_started @not_started end |
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
Corresponds to the JSON property ongoing
3924 3925 3926 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3924 def ongoing @ongoing end |
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Corresponds to the JSON property success
3929 3930 3931 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3929 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3936 3937 3938 3939 3940 3941 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3936 def update!(**args) @failed = args[:failed] if args.key?(:failed) @not_started = args[:not_started] if args.key?(:not_started) @ongoing = args[:ongoing] if args.key?(:ongoing) @success = args[:success] if args.key?(:success) end |