Class: Google::Apis::AlloydbV1beta::Stats
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::Stats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Upgrade stats for read pool instances.
Instance Attribute Summary collapse
-
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
-
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
-
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
-
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stats
constructor
A new instance of Stats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stats
Returns a new instance of Stats.
3848 3849 3850 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
Corresponds to the JSON property failed
3831 3832 3833 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3831 def failed @failed end |
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
Corresponds to the JSON property notStarted
3836 3837 3838 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3836 def not_started @not_started end |
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
Corresponds to the JSON property ongoing
3841 3842 3843 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3841 def ongoing @ongoing end |
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Corresponds to the JSON property success
3846 3847 3848 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3846 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3853 3854 3855 3856 3857 3858 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3853 def update!(**args) @failed = args[:failed] if args.key?(:failed) @not_started = args[:not_started] if args.key?(:not_started) @ongoing = args[:ongoing] if args.key?(:ongoing) @success = args[:success] if args.key?(:success) end |