Class: Google::Apis::AlloydbV1beta::Stats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Upgrade stats for read pool instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stats

Returns a new instance of Stats.



3829
3830
3831
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failedFixnum

Number of read pool instances which failed to upgrade. Corresponds to the JSON property failed

Returns:

  • (Fixnum)


3812
3813
3814
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3812

def failed
  @failed
end

#not_startedFixnum

Number of read pool instances for which upgrade has not started. Corresponds to the JSON property notStarted

Returns:

  • (Fixnum)


3817
3818
3819
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3817

def not_started
  @not_started
end

#ongoingFixnum

Number of read pool instances undergoing upgrade. Corresponds to the JSON property ongoing

Returns:

  • (Fixnum)


3822
3823
3824
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3822

def ongoing
  @ongoing
end

#successFixnum

Number of read pool instances successfully upgraded. Corresponds to the JSON property success

Returns:

  • (Fixnum)


3827
3828
3829
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3827

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3834
3835
3836
3837
3838
3839
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3834

def update!(**args)
  @failed = args[:failed] if args.key?(:failed)
  @not_started = args[:not_started] if args.key?(:not_started)
  @ongoing = args[:ongoing] if args.key?(:ongoing)
  @success = args[:success] if args.key?(:success)
end