Class: Google::Apis::AlloydbV1beta::Stats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Upgrade stats for read pool instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stats

Returns a new instance of Stats.



3823
3824
3825
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failedFixnum

Number of read pool instances which failed to upgrade. Corresponds to the JSON property failed

Returns:

  • (Fixnum)


3806
3807
3808
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3806

def failed
  @failed
end

#not_startedFixnum

Number of read pool instances for which upgrade has not started. Corresponds to the JSON property notStarted

Returns:

  • (Fixnum)


3811
3812
3813
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3811

def not_started
  @not_started
end

#ongoingFixnum

Number of read pool instances undergoing upgrade. Corresponds to the JSON property ongoing

Returns:

  • (Fixnum)


3816
3817
3818
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3816

def ongoing
  @ongoing
end

#successFixnum

Number of read pool instances successfully upgraded. Corresponds to the JSON property success

Returns:

  • (Fixnum)


3821
3822
3823
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3821

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3828
3829
3830
3831
3832
3833
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3828

def update!(**args)
  @failed = args[:failed] if args.key?(:failed)
  @not_started = args[:not_started] if args.key?(:not_started)
  @ongoing = args[:ongoing] if args.key?(:ongoing)
  @success = args[:success] if args.key?(:success)
end