Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Configuration for automatic backups

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Returns a new instance of StorageDatabasecenterPartnerapiV1mainBackupConfiguration.



3964
3965
3966
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automated_backup_enabledBoolean Also known as: automated_backup_enabled?

Whether customer visible automated backups are enabled on the instance. Corresponds to the JSON property automatedBackupEnabled

Returns:

  • (Boolean)


3948
3949
3950
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3948

def automated_backup_enabled
  @automated_backup_enabled
end

#backup_retention_settingsGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainRetentionSettings

Backup retention settings. Corresponds to the JSON property backupRetentionSettings



3954
3955
3956
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3954

def backup_retention_settings
  @backup_retention_settings
end

#point_in_time_recovery_enabledBoolean Also known as: point_in_time_recovery_enabled?

Whether point-in-time recovery is enabled. This is optional field, if the database service does not have this feature or metadata is not available in control plane, this can be omitted. Corresponds to the JSON property pointInTimeRecoveryEnabled

Returns:

  • (Boolean)


3961
3962
3963
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3961

def point_in_time_recovery_enabled
  @point_in_time_recovery_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3969
3970
3971
3972
3973
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3969

def update!(**args)
  @automated_backup_enabled = args[:automated_backup_enabled] if args.key?(:automated_backup_enabled)
  @backup_retention_settings = args[:backup_retention_settings] if args.key?(:backup_retention_settings)
  @point_in_time_recovery_enabled = args[:point_in_time_recovery_enabled] if args.key?(:point_in_time_recovery_enabled)
end