Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Configuration for automatic backups
Instance Attribute Summary collapse
-
#automated_backup_enabled ⇒ Boolean
(also: #automated_backup_enabled?)
Whether customer visible automated backups are enabled on the instance.
-
#backup_retention_settings ⇒ Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainRetentionSettings
Backup retention settings.
-
#point_in_time_recovery_enabled ⇒ Boolean
(also: #point_in_time_recovery_enabled?)
Whether point-in-time recovery is enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupConfiguration
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainBackupConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupConfiguration
Returns a new instance of StorageDatabasecenterPartnerapiV1mainBackupConfiguration.
3957 3958 3959 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automated_backup_enabled ⇒ Boolean Also known as: automated_backup_enabled?
Whether customer visible automated backups are enabled on the instance.
Corresponds to the JSON property automatedBackupEnabled
3941 3942 3943 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3941 def automated_backup_enabled @automated_backup_enabled end |
#backup_retention_settings ⇒ Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainRetentionSettings
Backup retention settings.
Corresponds to the JSON property backupRetentionSettings
3947 3948 3949 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3947 def backup_retention_settings @backup_retention_settings end |
#point_in_time_recovery_enabled ⇒ Boolean Also known as: point_in_time_recovery_enabled?
Whether point-in-time recovery is enabled. This is optional field, if the
database service does not have this feature or metadata is not available in
control plane, this can be omitted.
Corresponds to the JSON property pointInTimeRecoveryEnabled
3954 3955 3956 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3954 def point_in_time_recovery_enabled @point_in_time_recovery_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3962 3963 3964 3965 3966 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3962 def update!(**args) @automated_backup_enabled = args[:automated_backup_enabled] if args.key?(:automated_backup_enabled) @backup_retention_settings = args[:backup_retention_settings] if args.key?(:backup_retention_settings) @point_in_time_recovery_enabled = args[:point_in_time_recovery_enabled] if args.key?(:point_in_time_recovery_enabled) end |