Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupDrMetadata

Returns a new instance of StorageDatabasecenterPartnerapiV1mainBackupDrMetadata.



4020
4021
4022
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_configurationGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



3992
3993
3994
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3992

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupRun

A backup run. Corresponds to the JSON property backupRun



3997
3998
3999
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 3997

def backup_run
  @backup_run
end

#backupdr_configurationGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration

BackupDRConfiguration to capture the backup and disaster recovery details of database resource. Corresponds to the JSON property backupdrConfiguration



4003
4004
4005
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4003

def backupdr_configuration
  @backupdr_configuration
end

#full_resource_nameString

Required. Full resource name of this instance. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


4008
4009
4010
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4008

def full_resource_name
  @full_resource_name
end

#last_refresh_timeString

Required. Last time backup configuration was refreshed. Corresponds to the JSON property lastRefreshTime

Returns:

  • (String)


4013
4014
4015
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4013

def last_refresh_time
  @last_refresh_time
end

#resource_idGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



4018
4019
4020
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4018

def resource_id
  @resource_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4025
4026
4027
4028
4029
4030
4031
4032
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4025

def update!(**args)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
end