Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases.
Instance Attribute Summary collapse
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#resource_id ⇒ Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#signal_bool_value ⇒ Boolean
(also: #signal_bool_value?)
Signal data for boolean signals.
-
#signal_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData
Returns a new instance of StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData.
4143 4144 4145 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_resource_name ⇒ String
Required. Full Resource name of the source resource.
Corresponds to the JSON property fullResourceName
4120 4121 4122 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4120 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time signal was refreshed
Corresponds to the JSON property lastRefreshTime
4125 4126 4127 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4125 def last_refresh_time @last_refresh_time end |
#resource_id ⇒ Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
4130 4131 4132 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4130 def resource_id @resource_id end |
#signal_bool_value ⇒ Boolean Also known as: signal_bool_value?
Signal data for boolean signals.
Corresponds to the JSON property signalBoolValue
4135 4136 4137 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4135 def signal_bool_value @signal_bool_value end |
#signal_type ⇒ String
Required. Signal type of the signal
Corresponds to the JSON property signalType
4141 4142 4143 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4141 def signal_type @signal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4148 4149 4150 4151 4152 4153 4154 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4148 def update!(**args) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @resource_id = args[:resource_id] if args.key?(:resource_id) @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value) @signal_type = args[:signal_type] if args.key?(:signal_type) end |