Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainCustomMetadataData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Any custom metadata associated with the resource. e.g. A spanner instance can have multiple databases with its own unique metadata. Information for these individual databases can be captured in custom metadata data

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainCustomMetadataData

Returns a new instance of StorageDatabasecenterPartnerapiV1mainCustomMetadataData.



4156
4157
4158
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#internal_resource_metadataArray<Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata>

Metadata for individual internal resources in an instance. e.g. spanner instance can have multiple databases with unique configuration. Corresponds to the JSON property internalResourceMetadata



4154
4155
4156
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4154

def 
  @internal_resource_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4161
4162
4163
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4161

def update!(**args)
  @internal_resource_metadata = args[:internal_resource_metadata] if args.key?(:internal_resource_metadata)
end