Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

DatabaseResourceFeed is the top level proto to be used to ingest different database resource level events into Condor platform. Next ID: 13

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed.



4242
4243
4244
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupdr_metadataGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata

BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource. Corresponds to the JSON property backupdrMetadata



4181
4182
4183
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4181

def 
  @backupdr_metadata
end

#config_based_signal_dataGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData

Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases. Corresponds to the JSON property configBasedSignalData



4188
4189
4190
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4188

def config_based_signal_data
  @config_based_signal_data
end

#database_resource_signal_dataGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData

Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10 Corresponds to the JSON property databaseResourceSignalData



4195
4196
4197
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4195

def database_resource_signal_data
  @database_resource_signal_data
end

#feed_timestampString

Required. Timestamp when feed is generated. Corresponds to the JSON property feedTimestamp

Returns:

  • (String)


4200
4201
4202
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4200

def feed_timestamp
  @feed_timestamp
end

#feed_typeString

Required. Type feed to be ingested into condor Corresponds to the JSON property feedType

Returns:

  • (String)


4205
4206
4207
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4205

def feed_type
  @feed_type
end

#observability_metric_dataGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainObservabilityMetricData

Corresponds to the JSON property observabilityMetricData



4210
4211
4212
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4210

def observability_metric_data
  @observability_metric_data
end

#recommendation_signal_dataGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceRecommendationSignalData

Common model for database resource recommendation signal data. Corresponds to the JSON property recommendationSignalData



4215
4216
4217
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4215

def recommendation_signal_data
  @recommendation_signal_data
end

#resource_health_signal_dataGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData

Common model for database resource health signal data. Corresponds to the JSON property resourceHealthSignalData



4220
4221
4222
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4220

def resource_health_signal_data
  @resource_health_signal_data
end

#resource_idGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



4225
4226
4227
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4225

def resource_id
  @resource_id
end

#resource_metadataGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata

Common model for database resource instance metadata. Next ID: 32 Corresponds to the JSON property resourceMetadata



4230
4231
4232
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4230

def 
  @resource_metadata
end

#skip_ingestionBoolean Also known as: skip_ingestion?

Optional. If true, the feed won't be ingested by DB Center. This indicates that the feed is intentionally skipped. For example, BackupDR feeds are only needed for resources integrated with DB Center (e.g., CloudSQL, AlloyDB). Feeds for non-integrated resources (e.g., Compute Engine, Persistent Disk) can be skipped. Corresponds to the JSON property skipIngestion

Returns:

  • (Boolean)


4239
4240
4241
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4239

def skip_ingestion
  @skip_ingestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4247

def update!(**args)
  @backupdr_metadata = args[:backupdr_metadata] if args.key?(:backupdr_metadata)
  @config_based_signal_data = args[:config_based_signal_data] if args.key?(:config_based_signal_data)
  @database_resource_signal_data = args[:database_resource_signal_data] if args.key?(:database_resource_signal_data)
  @feed_timestamp = args[:feed_timestamp] if args.key?(:feed_timestamp)
  @feed_type = args[:feed_type] if args.key?(:feed_type)
  @observability_metric_data = args[:observability_metric_data] if args.key?(:observability_metric_data)
  @recommendation_signal_data = args[:recommendation_signal_data] if args.key?(:recommendation_signal_data)
  @resource_health_signal_data = args[:resource_health_signal_data] if args.key?(:resource_health_signal_data)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_metadata = args[:resource_metadata] if args.key?(:resource_metadata)
  @skip_ingestion = args[:skip_ingestion] if args.key?(:skip_ingestion)
end