Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

Metadata for individual internal resources in an instance. e.g. spanner instance can have multiple databases with unique configuration settings. Similarly bigtable can have multiple clusters within same bigtable instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata

Returns a new instance of StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata.



4862
4863
4864
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_configurationGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



4833
4834
4835
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4833

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainBackupRun

A backup run. Corresponds to the JSON property backupRun



4838
4839
4840
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4838

def backup_run
  @backup_run
end

#is_deletion_protection_enabledBoolean Also known as: is_deletion_protection_enabled?

Whether deletion protection is enabled for this internal resource. Corresponds to the JSON property isDeletionProtectionEnabled

Returns:

  • (Boolean)


4843
4844
4845
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4843

def is_deletion_protection_enabled
  @is_deletion_protection_enabled
end

#productGoogle::Apis::AlloydbV1beta::StorageDatabasecenterProtoCommonProduct

Product specification for Condor resources. Corresponds to the JSON property product



4849
4850
4851
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4849

def product
  @product
end

#resource_idGoogle::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



4854
4855
4856
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4854

def resource_id
  @resource_id
end

#resource_nameString

Required. internal resource name for spanner this will be database name e.g." spanner.googleapis.com/projects/123/abc/instances/inst1/databases/db1" Corresponds to the JSON property resourceName

Returns:

  • (String)


4860
4861
4862
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4860

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4867
4868
4869
4870
4871
4872
4873
4874
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4867

def update!(**args)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled)
  @product = args[:product] if args.key?(:product)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end