Class: Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainIpAddress
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::StorageDatabasecenterPartnerapiV1mainIpAddress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Used to send IP address information for a database resource.
Instance Attribute Summary collapse
-
#private_ip ⇒ String
The private IP address assigned to the resource within a Virtual Private Cloud (VPC).
-
#public_ip ⇒ String
The public IP address assigned to the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainIpAddress
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainIpAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainIpAddress
Returns a new instance of StorageDatabasecenterPartnerapiV1mainIpAddress.
4919 4920 4921 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_ip ⇒ String
The private IP address assigned to the resource within a Virtual Private Cloud
(VPC). This IP is only reachable from within the same VPC network. Stored in
standard string format (e.g., "10.0.0.2").
Corresponds to the JSON property privateIp
4911 4912 4913 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4911 def private_ip @private_ip end |
#public_ip ⇒ String
The public IP address assigned to the resource. This IP is reachable from the
internet. Stored in standard string format (e.g., "34.72.1.1").
Corresponds to the JSON property publicIp
4917 4918 4919 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4917 def public_ip @public_ip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4924 4925 4926 4927 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 4924 def update!(**args) @private_ip = args[:private_ip] if args.key?(:private_ip) @public_ip = args[:public_ip] if args.key?(:public_ip) end |