Class: Google::Apis::AlloydbV1beta::SupportedDatabaseFlag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb

Overview

SupportedDatabaseFlag gives general information about a database flag, like type and allowed values. This is a static value that is defined on the server side, and it cannot be modified by callers. To set the Database flags on a particular Instance, a caller should modify the Instance.database_flags field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SupportedDatabaseFlag

Returns a new instance of SupportedDatabaseFlag.



5570
5571
5572
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accepts_multiple_valuesBoolean Also known as: accepts_multiple_values?

Whether the database flag accepts multiple values. If true, a comma-separated list of stringified values may be specified. Corresponds to the JSON property acceptsMultipleValues

Returns:

  • (Boolean)


5510
5511
5512
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5510

def accepts_multiple_values
  @accepts_multiple_values
end

#flag_nameString

The name of the database flag, e.g. "max_allowed_packets". The is a possibly key for the Instance.database_flags map field. Corresponds to the JSON property flagName

Returns:

  • (String)


5517
5518
5519
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5517

def flag_name
  @flag_name
end

#integer_restrictionsGoogle::Apis::AlloydbV1beta::IntegerRestrictions

Restrictions on INTEGER type values. Corresponds to the JSON property integerRestrictions



5522
5523
5524
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5522

def integer_restrictions
  @integer_restrictions
end

#nameString

The name of the flag resource, following Google Cloud conventions, e.g.: * projects/project/locations/location/flags/flag This field currently has no semantic meaning. Corresponds to the JSON property name

Returns:

  • (String)


5529
5530
5531
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5529

def name
  @name
end

The recommended value for an INTEGER flag. Corresponds to the JSON property recommendedIntegerValue

Returns:

  • (Fixnum)


5534
5535
5536
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5534

def recommended_integer_value
  @recommended_integer_value
end

The recommended value for a STRING flag. Corresponds to the JSON property recommendedStringValue

Returns:

  • (String)


5539
5540
5541
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5539

def recommended_string_value
  @recommended_string_value
end

#requires_db_restartBoolean Also known as: requires_db_restart?

Whether setting or updating this flag on an Instance requires a database restart. If a flag that requires database restart is set, the backend will automatically restart the database (making sure to satisfy any availability SLO's). Corresponds to the JSON property requiresDbRestart

Returns:

  • (Boolean)


5547
5548
5549
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5547

def requires_db_restart
  @requires_db_restart
end

#scopeString

The scope of the flag. Corresponds to the JSON property scope

Returns:

  • (String)


5553
5554
5555
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5553

def scope
  @scope
end

#string_restrictionsGoogle::Apis::AlloydbV1beta::StringRestrictions

Restrictions on STRING type values Corresponds to the JSON property stringRestrictions



5558
5559
5560
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5558

def string_restrictions
  @string_restrictions
end

#supported_db_versionsArray<String>

Major database engine versions for which this flag is supported. Corresponds to the JSON property supportedDbVersions

Returns:

  • (Array<String>)


5563
5564
5565
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5563

def supported_db_versions
  @supported_db_versions
end

#value_typeString

Corresponds to the JSON property valueType

Returns:

  • (String)


5568
5569
5570
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5568

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5575

def update!(**args)
  @accepts_multiple_values = args[:accepts_multiple_values] if args.key?(:accepts_multiple_values)
  @flag_name = args[:flag_name] if args.key?(:flag_name)
  @integer_restrictions = args[:integer_restrictions] if args.key?(:integer_restrictions)
  @name = args[:name] if args.key?(:name)
  @recommended_integer_value = args[:recommended_integer_value] if args.key?(:recommended_integer_value)
  @recommended_string_value = args[:recommended_string_value] if args.key?(:recommended_string_value)
  @requires_db_restart = args[:requires_db_restart] if args.key?(:requires_db_restart)
  @scope = args[:scope] if args.key?(:scope)
  @string_restrictions = args[:string_restrictions] if args.key?(:string_restrictions)
  @supported_db_versions = args[:supported_db_versions] if args.key?(:supported_db_versions)
  @value_type = args[:value_type] if args.key?(:value_type)
end