Class: Google::Apis::AlloydbV1beta::SwitchoverClusterRequest
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::SwitchoverClusterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
Message for switching over to a cluster
Instance Attribute Summary collapse
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SwitchoverClusterRequest
constructor
A new instance of SwitchoverClusterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SwitchoverClusterRequest
Returns a new instance of SwitchoverClusterRequest.
5538 5539 5540 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5538 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server ignores the
request if it has already been completed. The server guarantees that for at
least 60 minutes since the first request. For example, consider a situation
where you make an initial request and the request times out. If you make the
request again with the same request ID, the server can check if the original
operation with the same request ID was received, and if so, ignores the second
request. This prevents clients from accidentally creating duplicate
commitments. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
5528 5529 5530 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5528 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, performs request validation, for example, permission checks
and any other type of validation, but does not actually execute the create
request.
Corresponds to the JSON property validateOnly
5535 5536 5537 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5535 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5543 5544 5545 5546 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5543 def update!(**args) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |