Class: Google::Apis::AlloydbV1beta::UpgradeClusterResponse
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1beta::UpgradeClusterResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1beta/classes.rb,
lib/google/apis/alloydb_v1beta/representations.rb,
lib/google/apis/alloydb_v1beta/representations.rb
Overview
UpgradeClusterResponse contains the response for upgrade cluster operation.
Instance Attribute Summary collapse
-
#cluster_upgrade_details ⇒ Array<Google::Apis::AlloydbV1beta::ClusterUpgradeDetails>
Array of upgrade details for the current cluster and all the secondary clusters associated with this cluster.
-
#message ⇒ String
A user friendly message summarising the upgrade operation details and the next steps for the user if there is any.
-
#status ⇒ String
Status of upgrade operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeClusterResponse
constructor
A new instance of UpgradeClusterResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeClusterResponse
Returns a new instance of UpgradeClusterResponse.
5762 5763 5764 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_upgrade_details ⇒ Array<Google::Apis::AlloydbV1beta::ClusterUpgradeDetails>
Array of upgrade details for the current cluster and all the secondary
clusters associated with this cluster.
Corresponds to the JSON property clusterUpgradeDetails
5749 5750 5751 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5749 def cluster_upgrade_details @cluster_upgrade_details end |
#message ⇒ String
A user friendly message summarising the upgrade operation details and the next
steps for the user if there is any.
Corresponds to the JSON property message
5755 5756 5757 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5755 def @message end |
#status ⇒ String
Status of upgrade operation.
Corresponds to the JSON property status
5760 5761 5762 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5760 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5767 5768 5769 5770 5771 |
# File 'lib/google/apis/alloydb_v1beta/classes.rb', line 5767 def update!(**args) @cluster_upgrade_details = args[:cluster_upgrade_details] if args.key?(:cluster_upgrade_details) @message = args[:message] if args.key?(:message) @status = args[:status] if args.key?(:status) end |